@@ -35,6 +35,7 @@ import java.util.Set;
 public class FilteringClassLoader extends ClassLoader implements ClassLoaderHierarchy {
     private static final ClassLoader EXT_CLASS_LOADER;
     private static final Set<String> SYSTEM_PACKAGES = new HashSet<String>();
+    public static final String DEFAULT_PACKAGE = "DEFAULT";
     private final Set<String> packageNames = new HashSet<String>();
     private final Set<String> packagePrefixes = new HashSet<String>();
     private final Set<String> resourcePrefixes = new HashSet<String>();
@@ -44,7 +45,7 @@ public class FilteringClassLoader extends ClassLoader implements ClassLoaderHier
     private final Set<String> disallowedPackagePrefixes = new HashSet<String>();
 
     static {
-        EXT_CLASS_LOADER = ClassLoader.getSystemClassLoader().getParent();
+        EXT_CLASS_LOADER = ClassLoaderUtils.getPlatformClassLoader();
         JavaMethod<ClassLoader, Package[]> method = JavaReflectionUtil.method(ClassLoader.class, Package[].class, "getPackages");
         Package[] systemPackages = method.invoke(EXT_CLASS_LOADER);
         for (Package p : systemPackages) {
@@ -174,10 +175,18 @@ public class FilteringClassLoader extends ClassLoader implements ClassLoaderHier
             if (className.startsWith(packagePrefix)) {
                 return true;
             }
+
+            if (packagePrefix.startsWith(DEFAULT_PACKAGE) && isInDefaultPackage(className)) {
+                return true;
+            }
         }
         return false;
     }
 
+    private boolean isInDefaultPackage(String className) {
+        return !className.contains(".");
+    }
+
     public static class Spec extends ClassLoaderSpec {
 
         final Set<String> packageNames = new HashSet<String>();
