@@ -17,6 +17,7 @@ package org.gradle.api.internal.artifacts.dependencies;
 
 import groovy.lang.Closure;
 import org.gradle.api.Action;
+import org.gradle.api.Nullable;
 import org.gradle.api.artifacts.Dependency;
 import org.gradle.api.artifacts.DependencyArtifact;
 import org.gradle.api.artifacts.ExcludeRule;
@@ -24,6 +25,7 @@ import org.gradle.api.artifacts.ExcludeRuleContainer;
 import org.gradle.api.artifacts.ModuleDependency;
 import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.api.internal.artifacts.DefaultExcludeRuleContainer;
+import org.gradle.util.DeprecationLogger;
 import org.gradle.util.GUtil;
 
 import java.util.HashSet;
@@ -33,10 +35,11 @@ import java.util.Set;
 public abstract class AbstractModuleDependency extends AbstractDependency implements ModuleDependency {
     private ExcludeRuleContainer excludeRuleContainer = new DefaultExcludeRuleContainer();
     private Set<DependencyArtifact> artifacts = new HashSet<DependencyArtifact>();
+    @Nullable
     private String configuration;
     private boolean transitive = true;
 
-    protected AbstractModuleDependency(String configuration) {
+    protected AbstractModuleDependency(@Nullable String configuration) {
         this.configuration = configuration;
     }
 
@@ -50,6 +53,7 @@ public abstract class AbstractModuleDependency extends AbstractDependency implem
     }
 
     public String getConfiguration() {
+        DeprecationLogger.nagUserOfDeprecated("ModuleDependency.getConfiguration()", "Use ModuleDependency.getTargetConfiguration() instead");
         return GUtil.elvis(configuration, Dependency.DEFAULT_CONFIGURATION);
     }
 
