@@ -16,18 +16,20 @@
 package org.gradle.api.internal.file;
 
 import groovy.lang.Closure;
-import org.codehaus.groovy.runtime.DefaultGroovyMethods;
+import org.gradle.api.Action;
 import org.gradle.api.file.*;
-import org.gradle.api.internal.file.collections.FilteredFileTree;
+import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.api.specs.Spec;
 import org.gradle.api.tasks.TaskDependency;
 import org.gradle.api.tasks.util.PatternFilterable;
 import org.gradle.api.tasks.util.PatternSet;
 import org.gradle.internal.Cast;
-import org.gradle.util.ConfigureUtil;
 
 import java.io.File;
-import java.util.*;
+import java.util.LinkedHashMap;
+import java.util.LinkedHashSet;
+import java.util.Map;
+import java.util.Set;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 public abstract class AbstractFileTree extends AbstractFileCollection implements FileTreeInternal {
@@ -54,8 +56,13 @@ public abstract class AbstractFileTree extends AbstractFileCollection implements
     }
 
     public FileTree matching(Closure filterConfigClosure) {
+        return matching(ClosureBackedAction.<PatternFilterable>of(filterConfigClosure));
+    }
+
+    @Override
+    public FileTree matching(Action<? super PatternFilterable> filterConfigAction) {
         PatternSet patternSet = new PatternSet();
-        ConfigureUtil.configure(filterConfigClosure, patternSet);
+        filterConfigAction.execute(patternSet);
         return matching(patternSet);
     }
 
@@ -108,7 +115,22 @@ public abstract class AbstractFileTree extends AbstractFileCollection implements
     }
 
     public FileTree visit(Closure closure) {
-        return visit(DefaultGroovyMethods.asType(closure, FileVisitor.class));
+        return visit(ClosureBackedAction.<FileVisitDetails>of(closure));
+    }
+
+    @Override
+    public FileTree visit(final Action<? super FileVisitDetails> visitor) {
+        return visit(new FileVisitor() {
+            @Override
+            public void visitDir(FileVisitDetails dirDetails) {
+                visitor.execute(dirDetails);
+            }
+
+            @Override
+            public void visitFile(FileVisitDetails fileDetails) {
+                visitor.execute(fileDetails);
+            }
+        });
     }
 
     @Override
@@ -116,7 +138,12 @@ public abstract class AbstractFileTree extends AbstractFileCollection implements
         visit(visitor);
     }
 
-    private static class FilteredFileTreeImpl extends AbstractFileTree implements FilteredFileTree {
+    @Override
+    public void visitRootElements(FileCollectionVisitor visitor) {
+        visitor.visitTree(this);
+    }
+
+    private static class FilteredFileTreeImpl extends AbstractFileTree {
         private final AbstractFileTree fileTree;
         private final Spec<FileTreeElement> spec;
 
@@ -162,11 +189,5 @@ public abstract class AbstractFileTree extends AbstractFileCollection implements
         public void visitTreeOrBackingFile(FileVisitor visitor) {
             fileTree.visitTreeOrBackingFile(visitor);
         }
-
-        @Override
-        public Spec<FileTreeElement> getFilter() {
-            return spec;
-        }
     }
-
 }
