@@ -16,7 +16,11 @@
 
 package org.gradle.api.internal.file.collections;
 
-import org.gradle.api.file.*;
+import org.gradle.api.file.DirectoryTree;
+import org.gradle.api.file.FileTreeElement;
+import org.gradle.api.file.FileVisitDetails;
+import org.gradle.api.file.FileVisitor;
+import org.gradle.api.file.RelativePath;
 import org.gradle.api.internal.file.DefaultFileVisitDetails;
 import org.gradle.api.internal.file.FileSystemSubset;
 import org.gradle.api.logging.Logger;
@@ -25,9 +29,9 @@ import org.gradle.api.specs.Spec;
 import org.gradle.api.tasks.util.PatternFilterable;
 import org.gradle.api.tasks.util.PatternSet;
 import org.gradle.internal.Factory;
+import org.gradle.internal.FileUtils;
 import org.gradle.internal.nativeintegration.filesystem.FileSystem;
 import org.gradle.internal.nativeintegration.services.FileSystems;
-import org.gradle.util.GFileUtils;
 import org.gradle.util.GUtil;
 
 import java.io.File;
@@ -45,30 +49,42 @@ import java.util.concurrent.atomic.AtomicBoolean;
  */
 public class DirectoryFileTree implements MinimalFileTree, PatternFilterableFileTree, RandomAccessFileCollection, LocalFileTree, DirectoryTree {
     private static final Logger LOGGER = Logging.getLogger(DirectoryFileTree.class);
+    private static final Factory<DirectoryWalker> DEFAULT_DIRECTORY_WALKER_FACTORY = new DefaultDirectoryWalkerFactory();
 
     private final File dir;
-
-    private PatternSet patternSet;
-    private boolean postfix;
-    private final FileSystem fileSystem = FileSystems.getDefault();
-    private static final Factory<DirectoryWalker> DEFAULT_DIRECTORY_WALKER_FACTORY = new DefaultDirectoryWalkerFactory();
+    private final PatternSet patternSet;
+    private final boolean postfix;
+    private final FileSystem fileSystem;
     private final Factory<DirectoryWalker> directoryWalkerFactory;
 
+    /**
+     * Use {@link DirectoryFileTreeFactory} instead.
+     */
+    @Deprecated
     public DirectoryFileTree(File dir) {
-        this(dir, new PatternSet());
+        this(dir, new PatternSet(), FileSystems.getDefault());
     }
 
+    /**
+     * Use {@link DirectoryFileTreeFactory} instead.
+     */
+    @Deprecated
     public DirectoryFileTree(File dir, PatternSet patternSet) {
-        this(dir, patternSet, DEFAULT_DIRECTORY_WALKER_FACTORY);
+        this(dir, patternSet, FileSystems.getDefault());
     }
 
-    DirectoryFileTree(File dir, PatternSet patternSet, Factory<DirectoryWalker> directoryWalkerFactory) {
+    public DirectoryFileTree(File dir, PatternSet patternSet, FileSystem fileSystem) {
+        this(FileUtils.canonicalize(dir), patternSet, DEFAULT_DIRECTORY_WALKER_FACTORY, fileSystem, false);
+    }
+
+    DirectoryFileTree(File dir, PatternSet patternSet, Factory<DirectoryWalker> directoryWalkerFactory, FileSystem fileSystem, boolean postfix) {
         this.patternSet = patternSet;
-        this.dir = GFileUtils.canonicalise(dir);
+        this.dir = dir;
         this.directoryWalkerFactory = directoryWalkerFactory;
+        this.fileSystem = fileSystem;
+        this.postfix = postfix;
     }
 
-
     public String getDisplayName() {
         String includes = patternSet.getIncludes().isEmpty() ? "" : String.format(" include %s", GUtil.toString(patternSet.getIncludes()));
         String excludes = patternSet.getExcludes().isEmpty() ? "" : String.format(" exclude %s", GUtil.toString(patternSet.getExcludes()));
@@ -95,7 +111,7 @@ public class DirectoryFileTree implements MinimalFileTree, PatternFilterableFile
     public DirectoryFileTree filter(PatternFilterable patterns) {
         PatternSet patternSet = this.patternSet.intersect();
         patternSet.copyFrom(patterns);
-        return new DirectoryFileTree(dir, patternSet, directoryWalkerFactory);
+        return new DirectoryFileTree(dir, patternSet, directoryWalkerFactory, fileSystem, postfix);
     }
 
     public boolean contains(File file) {
@@ -113,7 +129,7 @@ public class DirectoryFileTree implements MinimalFileTree, PatternFilterableFile
     }
 
     public void visit(FileVisitor visitor) {
-        visitFrom(visitor, dir, new RelativePath(false));
+        visitFrom(visitor, dir, RelativePath.EMPTY_ROOT);
     }
 
     /**
@@ -144,21 +160,23 @@ public class DirectoryFileTree implements MinimalFileTree, PatternFilterableFile
     }
 
     private void walkDir(File file, RelativePath path, FileVisitor visitor, Spec<FileTreeElement> spec, AtomicBoolean stopFlag) {
-        directoryWalkerFactory.create().walkDir(file, path, visitor, spec, stopFlag, fileSystem, postfix);
+        directoryWalkerFactory.create().walkDir(file, path, visitor, spec, stopFlag, postfix);
     }
 
-    static boolean isAllowed(FileTreeElement element, Spec<FileTreeElement> spec) {
+    static boolean isAllowed(FileTreeElement element, Spec<? super FileTreeElement> spec) {
         return spec.isSatisfiedBy(element);
     }
 
     /**
-     * Traverse directories (but not files) in postfix rather than prefix order.
+     * Returns a copy that traverses directories (but not files) in postfix rather than prefix order.
      *
      * @return {@code this}
      */
     public DirectoryFileTree postfix() {
-        postfix = true;
-        return this;
+        if (postfix) {
+            return this;
+        }
+        return new DirectoryFileTree(dir, patternSet, directoryWalkerFactory, fileSystem, true);
     }
 
     public PatternSet getPatternSet() {
