@@ -16,6 +16,9 @@
 
 package org.gradle.api.internal.project;
 
+import org.gradle.api.Action;
+import org.gradle.api.Incubating;
+import org.gradle.api.attributes.AttributesSchema;
 import org.gradle.api.Project;
 import org.gradle.api.ProjectEvaluationListener;
 import org.gradle.api.UnknownProjectException;
@@ -37,6 +40,7 @@ import org.gradle.internal.service.scopes.ServiceRegistryFactory;
 import org.gradle.internal.logging.StandardOutputCapture;
 import org.gradle.model.internal.registry.ModelRegistry;
 import org.gradle.model.internal.registry.ModelRegistryScope;
+import org.gradle.util.Path;
 
 public interface ProjectInternal extends Project, ProjectIdentifier, FileOperations, ProcessOperations, DomainObjectContext, DependencyMetaDataProvider, ModelRegistryScope, PluginAwareInternal {
 
@@ -97,4 +101,24 @@ public interface ProjectInternal extends Project, ProjectIdentifier, FileOperati
     void addDeferredConfiguration(Runnable configuration);
 
     void fireDeferredConfiguration();
+
+    AttributesSchema getAttributesSchema();
+
+    /**
+     * Returns a unique path for this project within its containing build.
+     */
+    Path getProjectPath();
+
+    /**
+     * Returns a unique path for this project within the current Gradle invocation.
+     */
+    Path getIdentityPath();
+
+    /**
+     * Configures the configuration attributes schema. The action is passed a {@link AttributesSchema} instance.
+     * @param configureAction the configure action
+     * @return the configured schema
+     */
+    @Incubating
+    AttributesSchema configurationAttributesSchema(Action<? super AttributesSchema> configureAction);
 }
