@@ -31,5 +31,5 @@ public interface PropertyAnnotationHandler {
     /**
      * Attaches the actions for the given property.
      */
-    void attachActions(PropertyActionContext context);
+    void attachActions(TaskPropertyActionContext context);
 }
