@@ -21,23 +21,31 @@ import com.google.common.hash.HashCode;
 import groovy.lang.Script;
 import org.codehaus.groovy.ast.ClassNode;
 import org.gradle.api.Action;
-import org.gradle.api.internal.changedetection.state.FileSnapshotter;
+import org.gradle.api.internal.hash.FileHasher;
 import org.gradle.api.internal.initialization.loadercache.ClassLoaderId;
 import org.gradle.groovy.scripts.ScriptSource;
 import org.gradle.internal.Cast;
 
 public class CrossBuildInMemoryCachingScriptClassCache {
-    private final Cache<ScriptCacheKey, CachedCompiledScript> cachedCompiledScripts = CacheBuilder.newBuilder().maximumSize(100).recordStats().build();
-    private final FileSnapshotter snapshotter;
 
-    public CrossBuildInMemoryCachingScriptClassCache(FileSnapshotter snapshotter) {
-        this.snapshotter = snapshotter;
+    private final Cache<ScriptCacheKey, CachedCompiledScript> cachedCompiledScripts =
+        CacheBuilder.newBuilder().maximumSize(100).recordStats().build();
+
+    private final FileHasher hasher;
+
+    public CrossBuildInMemoryCachingScriptClassCache(FileHasher hasher) {
+        this.hasher = hasher;
     }
 
-    public <T extends Script, M> CompiledScript<T, M> getOrCompile(ScriptSource source, ClassLoader classLoader, ClassLoaderId classLoaderId, CompileOperation<M> operation, Class<T> scriptBaseClass, Action<? super ClassNode> verifier, ScriptClassCompiler delegate) {
+    public <T extends Script, M> CompiledScript<T, M> getOrCompile(ScriptSource source, ClassLoader classLoader,
+                                                                   ClassLoaderId classLoaderId,
+                                                                   CompileOperation<M> operation,
+                                                                   Class<T> scriptBaseClass,
+                                                                   Action<? super ClassNode> verifier,
+                                                                   ScriptClassCompiler delegate) {
         ScriptCacheKey key = new ScriptCacheKey(source.getClassName(), classLoader, operation.getId());
         CachedCompiledScript cached = cachedCompiledScripts.getIfPresent(key);
-        HashCode hash = snapshotter.snapshot(source.getResource()).getHash();
+        HashCode hash = hasher.hash(source.getResource());
         if (cached != null) {
             if (hash.equals(cached.hash)) {
                 return Cast.uncheckedCast(cached.compiledScript);
