@@ -24,10 +24,10 @@ import org.gradle.internal.concurrent.Stoppable;
 /**
  * This was the old Gradle embedding API (it used to be in the public `org.gradle` package). It is now internal and is due to be merged into {@link org.gradle.internal.invocation.BuildController}.
  */
-public abstract class GradleLauncher implements Stoppable {
+public interface GradleLauncher extends Stoppable {
 
-    public abstract GradleInternal getGradle();
-    public abstract SettingsInternal getSettings();
+    GradleInternal getGradle();
+    SettingsInternal getSettings();
 
     /**
      * <p>Executes the build for this {@code GradleLauncher} instance and returns the result.</p>
@@ -35,7 +35,7 @@ public abstract class GradleLauncher implements Stoppable {
      * @return The result. Never returns null.
      * @throws ReportedException On build failure. The failure will have been logged.
      */
-    public abstract BuildResult run() throws ReportedException;
+    BuildResult run() throws ReportedException;
 
     /**
      * Evaluates the settings for this build. The information about available tasks and projects is accessible via the {@link org.gradle.api.invocation.Gradle#getRootProject()} object.
@@ -43,7 +43,7 @@ public abstract class GradleLauncher implements Stoppable {
      * @return The result. Never returns null.
      * @throws ReportedException On build failure. The failure will have been logged.
      */
-    public abstract BuildResult load() throws ReportedException;
+    BuildResult load() throws ReportedException;
 
     /**
      * Evaluates the settings and all the projects. The information about available tasks and projects is accessible via the {@link org.gradle.api.invocation.Gradle#getRootProject()} object.
@@ -51,28 +51,29 @@ public abstract class GradleLauncher implements Stoppable {
      * @return The result. Never returns null.
      * @throws ReportedException On build failure. The failure will have been logged.
      */
-    public abstract BuildResult getBuildAnalysis() throws ReportedException;
+    BuildResult getBuildAnalysis() throws ReportedException;
 
     /**
-     * <p>Adds a listener to this build instance. The listener is notified of events which occur during the execution of the build. See {@link org.gradle.api.invocation.Gradle#addListener(Object)} for
-     * supported listener types.</p>
-     *
-     * @param listener The listener to add. Has no effect if the listener has already been added.
+     * <p>Adds a listener to this build instance. Receives events for this build only.
      */
-    public abstract void addListener(Object listener);
+    void addListener(Object listener);
+
+    /**
+     * <p>Adds a nested listener to this build instance. Receives events for this build and all nested builds.
+     */
+    void addNestedListener(Object listener);
 
     /**
      * <p>Adds a {@link StandardOutputListener} to this build instance. The listener is notified of any text written to standard output by Gradle's logging system
      *
      * @param listener The listener to add. Has no effect if the listener has already been added.
      */
-    public abstract void addStandardOutputListener(StandardOutputListener listener);
+    void addStandardOutputListener(StandardOutputListener listener);
 
     /**
      * <p>Adds a {@link StandardOutputListener} to this build instance. The listener is notified of any text written to standard error by Gradle's logging system
      *
      * @param listener The listener to add. Has no effect if the listener has already been added.
      */
-    public abstract void addStandardErrorListener(StandardOutputListener listener);
-
+    void addStandardErrorListener(StandardOutputListener listener);
 }
