@@ -22,6 +22,7 @@ import org.gradle.BuildAdapter;
 import org.gradle.BuildListener;
 import org.gradle.StartParameter;
 import org.gradle.api.Action;
+import org.gradle.api.Nullable;
 import org.gradle.api.Project;
 import org.gradle.api.ProjectEvaluationListener;
 import org.gradle.api.initialization.IncludedBuild;
@@ -33,9 +34,9 @@ import org.gradle.api.internal.plugins.DefaultObjectConfigurationAction;
 import org.gradle.api.internal.plugins.PluginManagerInternal;
 import org.gradle.api.internal.project.AbstractPluginAware;
 import org.gradle.api.internal.project.ProjectInternal;
-import org.gradle.api.internal.tasks.cache.config.TaskCachingInternal;
 import org.gradle.api.invocation.Gradle;
-import org.gradle.api.tasks.TaskCaching;
+import org.gradle.caching.internal.BuildCacheConfiguration;
+import org.gradle.caching.internal.BuildCacheConfigurationInternal;
 import org.gradle.configuration.ScriptPluginFactory;
 import org.gradle.execution.TaskGraphExecuter;
 import org.gradle.initialization.ClassLoaderScopeRegistry;
@@ -48,6 +49,7 @@ import org.gradle.internal.service.scopes.ServiceRegistryFactory;
 import org.gradle.listener.ActionBroadcast;
 import org.gradle.listener.ClosureBackedMethodInvocationDispatch;
 import org.gradle.util.GradleVersion;
+import org.gradle.util.Path;
 
 import javax.inject.Inject;
 import java.io.File;
@@ -58,17 +60,17 @@ import java.util.NoSuchElementException;
 public class DefaultGradle extends AbstractPluginAware implements GradleInternal {
     private ProjectInternal rootProject;
     private ProjectInternal defaultProject;
-    private final Gradle parent;
+    private final GradleInternal parent;
     private final StartParameter startParameter;
     private final ServiceRegistry services;
     private final ListenerBroadcast<BuildListener> buildListenerBroadcast;
     private final ListenerBroadcast<ProjectEvaluationListener> projectEvaluationListenerBroadcast;
     private final Collection<IncludedBuild> includedBuilds = Lists.newArrayList();
     private ActionBroadcast<Project> rootProjectActions = new ActionBroadcast<Project>();
-
+    private Path identityPath;
     private final ClassLoaderScope classLoaderScope;
 
-    public DefaultGradle(Gradle parent, StartParameter startParameter, ServiceRegistryFactory parentRegistry) {
+    public DefaultGradle(GradleInternal parent, StartParameter startParameter, ServiceRegistryFactory parentRegistry) {
         this.parent = parent;
         this.startParameter = startParameter;
         this.services = parentRegistry.createFor(this);
@@ -89,7 +91,42 @@ public class DefaultGradle extends AbstractPluginAware implements GradleInternal
         return rootProject == null ? "build" : ("build '" + rootProject.getName() + "'");
     }
 
-    public Gradle getParent() {
+    @Override
+    public Path getIdentityPath() {
+        Path path = findIdentityPath();
+        if (path == null) {
+            // Not known yet
+            throw new IllegalStateException("Root project has not been attached.");
+        }
+        return path;
+    }
+
+    @Nullable
+    @Override
+    public Path findIdentityPath() {
+        if (identityPath == null) {
+            if (parent == null) {
+                identityPath = Path.ROOT;
+            } else {
+                if (rootProject == null) {
+                    // Not known yet
+                    return null;
+                }
+                identityPath = parent.getIdentityPath().child(rootProject.getName());
+            }
+        }
+        return identityPath;
+    }
+
+    @Override
+    public void setIdentityPath(Path path) {
+        if (identityPath != null && !path.equals(identityPath)) {
+            throw new IllegalStateException("Identity path already set");
+        }
+        identityPath = path;
+    }
+
+    public GradleInternal getParent() {
         return parent;
     }
 
@@ -213,8 +250,8 @@ public class DefaultGradle extends AbstractPluginAware implements GradleInternal
     }
 
     @Override
-    public void taskCaching(Action<? super TaskCaching> action) {
-        action.execute(getTaskCaching());
+    public void buildCache(Action<? super BuildCacheConfiguration> action) {
+        action.execute(getBuildCache());
     }
 
     public Gradle getGradle() {
@@ -260,7 +297,7 @@ public class DefaultGradle extends AbstractPluginAware implements GradleInternal
     }
 
     @Inject
-    public TaskCachingInternal getTaskCaching() {
+    public BuildCacheConfigurationInternal getBuildCache() {
         throw new UnsupportedOperationException();
     }
 
