@@ -17,20 +17,26 @@
 package org.gradle.api.internal.artifacts.dsl;
 
 import org.apache.tools.ant.Task;
+import org.gradle.api.artifacts.ConfigurablePublishArtifact;
 import org.gradle.api.artifacts.PublishArtifact;
 import org.gradle.api.internal.artifacts.Module;
 import org.gradle.api.internal.artifacts.configurations.DependencyMetaDataProvider;
 import org.gradle.api.internal.artifacts.publish.ArchivePublishArtifact;
+import org.gradle.api.internal.artifacts.publish.DecoratingPublishArtifact;
 import org.gradle.api.internal.artifacts.publish.DefaultPublishArtifact;
 import org.gradle.api.tasks.bundling.AbstractArchiveTask;
 import org.gradle.internal.Factory;
 import org.gradle.internal.exceptions.DiagnosticsVisitor;
 import org.gradle.internal.reflect.Instantiator;
-import org.gradle.internal.typeconversion.*;
+import org.gradle.internal.typeconversion.MapKey;
+import org.gradle.internal.typeconversion.MapNotationConverter;
+import org.gradle.internal.typeconversion.NotationParser;
+import org.gradle.internal.typeconversion.NotationParserBuilder;
+import org.gradle.internal.typeconversion.TypedNotationConverter;
 
 import java.io.File;
 
-public class PublishArtifactNotationParserFactory implements Factory<NotationParser<Object, PublishArtifact>> {
+public class PublishArtifactNotationParserFactory implements Factory<NotationParser<Object, ConfigurablePublishArtifact>> {
     private final Instantiator instantiator;
     private final DependencyMetaDataProvider metaDataProvider;
 
@@ -39,33 +45,45 @@ public class PublishArtifactNotationParserFactory implements Factory<NotationPar
         this.metaDataProvider = metaDataProvider;
     }
 
-    public NotationParser<Object, PublishArtifact> create() {
+    public NotationParser<Object, ConfigurablePublishArtifact> create() {
         FileNotationConverter fileConverter = new FileNotationConverter();
         return NotationParserBuilder
-                .toType(PublishArtifact.class)
+                .toType(ConfigurablePublishArtifact.class)
+                .converter(new DecoratingConverter())
                 .converter(new ArchiveTaskNotationConverter())
                 .converter(new FileMapNotationConverter(fileConverter))
                 .converter(fileConverter)
                 .toComposite();
     }
 
-    private class ArchiveTaskNotationConverter extends TypedNotationConverter<AbstractArchiveTask, PublishArtifact> {
+    private class DecoratingConverter extends TypedNotationConverter<PublishArtifact, ConfigurablePublishArtifact> {
+        private DecoratingConverter() {
+            super(PublishArtifact.class);
+        }
+
+        @Override
+        protected ConfigurablePublishArtifact parseType(PublishArtifact notation) {
+            return instantiator.newInstance(DecoratingPublishArtifact.class, notation);
+        }
+    }
+
+    private class ArchiveTaskNotationConverter extends TypedNotationConverter<AbstractArchiveTask, ConfigurablePublishArtifact> {
         private ArchiveTaskNotationConverter() {
             super(AbstractArchiveTask.class);
         }
 
         @Override
         public void describe(DiagnosticsVisitor visitor) {
-            visitor.candidate("Instances of AbstractArchiveTask").example("jar.");
+            visitor.candidate("Instances of AbstractArchiveTask").example("jar");
         }
 
         @Override
-        protected PublishArtifact parseType(AbstractArchiveTask notation) {
+        protected ConfigurablePublishArtifact parseType(AbstractArchiveTask notation) {
             return instantiator.newInstance(ArchivePublishArtifact.class, notation);
         }
     }
 
-    private class FileMapNotationConverter extends MapNotationConverter<PublishArtifact> {
+    private class FileMapNotationConverter extends MapNotationConverter<ConfigurablePublishArtifact> {
         private final FileNotationConverter fileConverter;
 
         private FileMapNotationConverter(FileNotationConverter fileConverter) {
@@ -77,18 +95,17 @@ public class PublishArtifactNotationParserFactory implements Factory<NotationPar
         }
     }
 
-    private class FileNotationConverter extends TypedNotationConverter<File, PublishArtifact> {
+    private class FileNotationConverter extends TypedNotationConverter<File, ConfigurablePublishArtifact> {
         private FileNotationConverter() {
             super(File.class);
         }
 
         @Override
-        protected PublishArtifact parseType(File file) {
+        protected ConfigurablePublishArtifact parseType(File file) {
             Module module = metaDataProvider.getModule();
             ArtifactFile artifactFile = new ArtifactFile(file, module.getVersion());
             return instantiator.newInstance(DefaultPublishArtifact.class, artifactFile.getName(), artifactFile.getExtension(),
-                                            artifactFile.getExtension() == null? "":artifactFile.getExtension(),
-                                            artifactFile.getClassifier(), null, file, new Task[0]);
+                artifactFile.getExtension(), artifactFile.getClassifier(), null, file, new Task[0]);
         }
     }
 }
