@@ -25,18 +25,24 @@ import org.gradle.api.artifacts.ResolvedDependency;
 import org.gradle.api.artifacts.UnresolvedDependency;
 import org.gradle.api.artifacts.component.ComponentIdentifier;
 import org.gradle.api.artifacts.result.ResolutionResult;
+import org.gradle.api.artifacts.result.ResolvedArtifactResult;
 import org.gradle.api.internal.artifacts.ConfigurationResolver;
 import org.gradle.api.internal.artifacts.DefaultModuleVersionIdentifier;
 import org.gradle.api.internal.artifacts.Module;
 import org.gradle.api.internal.artifacts.ResolverResults;
 import org.gradle.api.internal.artifacts.component.ComponentIdentifierFactory;
 import org.gradle.api.internal.artifacts.configurations.ConfigurationInternal;
-import org.gradle.api.internal.artifacts.ivyservice.resolveengine.projectresult.DefaultResolvedLocalComponentsResultBuilder;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.ArtifactVisitor;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.SelectedArtifactSet;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.artifact.VisitedArtifactSet;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.projectresult.ResolvedLocalComponentsResult;
+import org.gradle.api.internal.artifacts.ivyservice.resolveengine.projectresult.ResolvedLocalComponentsResultGraphVisitor;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.result.DefaultResolutionResultBuilder;
+import org.gradle.api.internal.attributes.AttributeContainerInternal;
 import org.gradle.api.specs.Spec;
 
 import java.io.File;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.Set;
 
@@ -50,73 +56,144 @@ public class ShortCircuitEmptyConfigurationResolver implements ConfigurationReso
     }
 
     @Override
-    public void resolve(ConfigurationInternal configuration, ResolverResults results) throws ResolveException {
+    public void resolveBuildDependencies(ConfigurationInternal configuration, ResolverResults result) {
         if (configuration.getAllDependencies().isEmpty()) {
-            Module module = configuration.getModule();
-            ModuleVersionIdentifier id = DefaultModuleVersionIdentifier.newId(module);
-            ComponentIdentifier componentIdentifier = componentIdentifierFactory.createComponentIdentifier(module);
-            ResolutionResult emptyResult = DefaultResolutionResultBuilder.empty(id, componentIdentifier);
-            ResolvedLocalComponentsResult emptyProjectResult = new DefaultResolvedLocalComponentsResultBuilder(false).complete();
-            results.resolved(emptyResult, emptyProjectResult);
+            emptyGraph(configuration, result);
         } else {
-            delegate.resolve(configuration, results);
+            delegate.resolveBuildDependencies(configuration, result);
         }
     }
 
+    @Override
+    public void resolveGraph(ConfigurationInternal configuration, ResolverResults results) throws ResolveException {
+        if (configuration.getAllDependencies().isEmpty()) {
+            emptyGraph(configuration, results);
+        } else {
+            delegate.resolveGraph(configuration, results);
+        }
+    }
+
+    private void emptyGraph(ConfigurationInternal configuration, ResolverResults results) {
+        Module module = configuration.getModule();
+        ModuleVersionIdentifier id = DefaultModuleVersionIdentifier.newId(module);
+        ComponentIdentifier componentIdentifier = componentIdentifierFactory.createComponentIdentifier(module);
+        ResolutionResult emptyResult = DefaultResolutionResultBuilder.empty(id, componentIdentifier);
+        ResolvedLocalComponentsResult emptyProjectResult = new ResolvedLocalComponentsResultGraphVisitor();
+        results.graphResolved(emptyResult, emptyProjectResult, new EmptyResults());
+    }
+
     @Override
     public void resolveArtifacts(ConfigurationInternal configuration, ResolverResults results) throws ResolveException {
         if (configuration.getAllDependencies().isEmpty()) {
-            results.withResolvedConfiguration(new EmptyResolvedConfiguration());
+            results.artifactsResolved(new EmptyResolvedConfiguration(), new EmptyResults());
         } else {
             delegate.resolveArtifacts(configuration, results);
         }
     }
 
+    private static class EmptyResults implements VisitedArtifactSet, SelectedArtifactSet {
+        @Override
+        public SelectedArtifactSet select(Spec<? super Dependency> dependencySpec, AttributeContainerInternal attributes) {
+            return this;
+        }
+
+        @Override
+        public <T extends Collection<Object>> T collectBuildDependencies(T dest) {
+            return dest;
+        }
+
+        @Override
+        public void visitArtifacts(ArtifactVisitor visitor) {
+        }
+
+        @Override
+        public <T extends Collection<? super File>> T collectFiles(T dest) throws ResolveException {
+            return dest;
+        }
+
+        @Override
+        public <T extends Collection<? super ResolvedArtifactResult>> T collectArtifacts(T dest) throws ResolveException {
+            return dest;
+        }
+    }
+
     private static class EmptyResolvedConfiguration implements ResolvedConfiguration {
 
+        @Override
         public boolean hasError() {
             return false;
         }
 
+        @Override
         public LenientConfiguration getLenientConfiguration() {
             return new LenientConfiguration() {
+                @Override
+                public Set<ResolvedDependency> getFirstLevelModuleDependencies() {
+                    return Collections.emptySet();
+                }
+
+                @Override
                 public Set<ResolvedDependency> getFirstLevelModuleDependencies(Spec<? super Dependency> dependencySpec) {
                     return Collections.emptySet();
                 }
 
+                @Override
                 public Set<ResolvedDependency> getAllModuleDependencies() {
                     return Collections.emptySet();
                 }
 
+                @Override
                 public Set<UnresolvedDependency> getUnresolvedModuleDependencies() {
                     return Collections.emptySet();
                 }
 
+                @Override
+                public Set<File> getFiles() {
+                    return Collections.emptySet();
+                }
+
+                @Override
                 public Set<File> getFiles(Spec<? super Dependency> dependencySpec) {
                     return Collections.emptySet();
                 }
 
+                @Override
+                public Set<ResolvedArtifact> getArtifacts() {
+                    return Collections.emptySet();
+                }
+
+                @Override
                 public Set<ResolvedArtifact> getArtifacts(Spec<? super Dependency> dependencySpec) {
                     return Collections.emptySet();
                 }
             };
         }
 
+        @Override
         public void rethrowFailure() throws ResolveException {
         }
 
+        @Override
+        public Set<File> getFiles() throws ResolveException {
+            return Collections.emptySet();
+        }
+
+        @Override
         public Set<File> getFiles(Spec<? super Dependency> dependencySpec) {
             return Collections.emptySet();
         }
 
+        @Override
         public Set<ResolvedDependency> getFirstLevelModuleDependencies() {
             return Collections.emptySet();
         }
 
+        @Override
         public Set<ResolvedDependency> getFirstLevelModuleDependencies(Spec<? super Dependency> dependencySpec) throws ResolveException {
             return Collections.emptySet();
         }
 
+        @Override
         public Set<ResolvedArtifact> getResolvedArtifacts() {
             return Collections.emptySet();
         }
