@@ -15,11 +15,10 @@
  */
 package org.gradle.api.internal.artifacts.ivyservice.moduleconverter;
 
-import org.gradle.api.artifacts.Configuration;
+import org.gradle.api.internal.artifacts.configurations.ConfigurationInternal;
 import org.gradle.api.internal.artifacts.configurations.Configurations;
-import org.gradle.api.internal.artifacts.configurations.DirectBuildDependencies;
+import org.gradle.api.internal.artifacts.configurations.OutgoingVariant;
 import org.gradle.api.internal.artifacts.ivyservice.moduleconverter.dependencies.DependenciesToModuleDescriptorConverter;
-import org.gradle.api.tasks.TaskDependency;
 import org.gradle.internal.component.local.model.BuildableLocalComponentMetadata;
 
 import java.util.Collection;
@@ -32,28 +31,30 @@ public class DefaultConfigurationComponentMetaDataBuilder implements Configurati
         this.dependenciesConverter = dependenciesConverter;
     }
 
-    public void addConfigurations(BuildableLocalComponentMetadata metaData, Collection<? extends Configuration> configurations) {
-        for (Configuration configuration : configurations) {
+    public void addConfigurations(BuildableLocalComponentMetadata metaData, Collection<? extends ConfigurationInternal> configurations) {
+        for (ConfigurationInternal configuration : configurations) {
             addConfiguration(metaData, configuration);
+            dependenciesConverter.addDependencyDescriptors(metaData, configuration);
+            OutgoingVariant outgoingVariant = configuration.convertToOutgoingVariant();
+            metaData.addArtifacts(configuration.getName(), outgoingVariant.getArtifacts());
+            for (OutgoingVariant variant : outgoingVariant.getChildren()) {
+                metaData.addVariant(configuration.getName(), variant);
+            }
         }
-        addDependencies(metaData, configurations);
-        addArtifacts(metaData, configurations);
     }
 
-    private void addConfiguration(BuildableLocalComponentMetadata metaData, Configuration configuration) {
+    private void addConfiguration(BuildableLocalComponentMetadata metaData, ConfigurationInternal configuration) {
         Set<String> hierarchy = Configurations.getNames(configuration.getHierarchy());
         Set<String> extendsFrom = Configurations.getNames(configuration.getExtendsFrom());
-        TaskDependency directBuildDependencies = DirectBuildDependencies.forDependenciesAndArtifacts(configuration);
-        metaData.addConfiguration(configuration.getName(), configuration.getDescription(), extendsFrom, hierarchy, configuration.isVisible(), configuration.isTransitive(), directBuildDependencies);
+        metaData.addConfiguration(configuration.getName(),
+            configuration.getDescription(),
+            extendsFrom,
+            hierarchy,
+            configuration.isVisible(),
+            configuration.isTransitive(),
+            configuration.getAttributes().asImmutable(),
+            configuration.isCanBeConsumed(),
+            configuration.isCanBeResolved());
     }
 
-    private void addDependencies(BuildableLocalComponentMetadata metaData, Collection<? extends Configuration> configurations) {
-        dependenciesConverter.addDependencyDescriptors(metaData, configurations);
-    }
-
-    private void addArtifacts(BuildableLocalComponentMetadata metaData, Collection<? extends Configuration> configurations) {
-        for (Configuration configuration : configurations) {
-            metaData.addArtifacts(configuration.getName(), configuration.getArtifacts());
-        }
-    }
 }
