@@ -26,12 +26,12 @@ import java.util.Set;
  */
 public interface DependencyGraphNode {
     /**
-     * Returns a simple id for this configuration, unique across configurations in the same graph.
+     * Returns a simple id for this node, unique across node in the same graph.
      * This id cannot be used across graphs.
      */
-    Long getResultId();
+    Long getNodeId();
 
-    ResolvedConfigurationIdentifier getNodeId();
+    ResolvedConfigurationIdentifier getResolvedConfigurationId();
 
     DependencyGraphComponent getOwner();
 
