@@ -17,69 +17,103 @@
 package org.gradle.internal.component.local.model;
 
 import com.google.common.collect.ArrayListMultimap;
+import com.google.common.collect.ImmutableList;
+import com.google.common.collect.ImmutableSet;
+import com.google.common.collect.LinkedHashMultimap;
 import com.google.common.collect.Lists;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Multimap;
-import com.google.common.collect.Sets;
+import com.google.common.collect.SetMultimap;
 import org.gradle.api.artifacts.ModuleVersionIdentifier;
 import org.gradle.api.artifacts.PublishArtifact;
 import org.gradle.api.artifacts.component.ComponentIdentifier;
+import org.gradle.api.attributes.AttributesSchema;
+import org.gradle.api.internal.artifacts.configurations.OutgoingVariant;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.excludes.ModuleExclusion;
 import org.gradle.api.internal.artifacts.ivyservice.resolveengine.excludes.ModuleExclusions;
-import org.gradle.api.tasks.TaskDependency;
+import org.gradle.api.internal.attributes.AttributeContainerInternal;
 import org.gradle.internal.component.model.ComponentArtifactMetadata;
 import org.gradle.internal.component.model.ComponentResolveMetadata;
-import org.gradle.internal.component.model.DependencyMetadata;
+import org.gradle.internal.component.model.DefaultVariantMetadata;
 import org.gradle.internal.component.model.Exclude;
 import org.gradle.internal.component.model.IvyArtifactName;
 import org.gradle.internal.component.model.LocalOriginDependencyMetadata;
 import org.gradle.internal.component.model.ModuleSource;
+import org.gradle.internal.component.model.VariantMetadata;
 
-import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
 public class DefaultLocalComponentMetadata implements LocalComponentMetadata, BuildableLocalComponentMetadata {
     private final Map<String, DefaultLocalConfigurationMetadata> allConfigurations = Maps.newHashMap();
-    private final Multimap<String, ComponentArtifactMetadata> allArtifacts = ArrayListMultimap.create();
+    private final Multimap<String, LocalComponentArtifactMetadata> allArtifacts = ArrayListMultimap.create();
+    private final Multimap<String, LocalFileDependencyMetadata> allFiles = ArrayListMultimap.create();
+    private final SetMultimap<String, DefaultVariantMetadata> allVariants = LinkedHashMultimap.create();
     private final List<LocalOriginDependencyMetadata> allDependencies = Lists.newArrayList();
     private final List<Exclude> allExcludes = Lists.newArrayList();
     private final ModuleVersionIdentifier id;
     private final ComponentIdentifier componentIdentifier;
     private final String status;
+    private final AttributesSchema attributesSchema;
 
-    public DefaultLocalComponentMetadata(ModuleVersionIdentifier id, ComponentIdentifier componentIdentifier, String status) {
+    public DefaultLocalComponentMetadata(ModuleVersionIdentifier id, ComponentIdentifier componentIdentifier, String status, AttributesSchema attributesSchema) {
         this.id = id;
         this.componentIdentifier = componentIdentifier;
         this.status = status;
+        this.attributesSchema = attributesSchema;
     }
 
+    @Override
     public ModuleVersionIdentifier getId() {
         return id;
     }
 
+    @Override
     public void addArtifacts(String configuration, Iterable<? extends PublishArtifact> artifacts) {
         for (PublishArtifact artifact : artifacts) {
-            ComponentArtifactMetadata artifactMetadata = new PublishArtifactLocalArtifactMetadata(componentIdentifier, componentIdentifier.getDisplayName(), artifact);
+            LocalComponentArtifactMetadata artifactMetadata = new PublishArtifactLocalArtifactMetadata(componentIdentifier, artifact);
             addArtifact(configuration, artifactMetadata);
         }
     }
 
-    public void addArtifact(String configuration, ComponentArtifactMetadata artifactMetadata) {
+    public void addArtifact(String configuration, LocalComponentArtifactMetadata artifactMetadata) {
         allArtifacts.put(configuration, artifactMetadata);
     }
 
-    public void addConfiguration(String name, String description, Set<String> extendsFrom, Set<String> hierarchy, boolean visible, boolean transitive, TaskDependency buildDependencies) {
+    @Override
+    public void addVariant(String configuration, OutgoingVariant variant) {
+        Set<LocalComponentArtifactMetadata> artifacts;
+        if (variant.getArtifacts().isEmpty()) {
+            artifacts = ImmutableSet.of();
+        } else {
+            ImmutableSet.Builder<LocalComponentArtifactMetadata> builder = ImmutableSet.builder();
+            for (PublishArtifact artifact : variant.getArtifacts()) {
+                builder.add(new PublishArtifactLocalArtifactMetadata(componentIdentifier, artifact));
+            }
+            artifacts = builder.build();
+        }
+        allVariants.put(configuration, new DefaultVariantMetadata(variant.getAttributes().asImmutable(), artifacts));
+    }
+
+    @Override
+    public void addFiles(String configuration, LocalFileDependencyMetadata files) {
+        allFiles.put(configuration, files);
+    }
+
+    @Override
+    public void addConfiguration(String name, String description, Set<String> extendsFrom, Set<String> hierarchy, boolean visible, boolean transitive, AttributeContainerInternal attributes, boolean canBeConsumed, boolean canBeResolved) {
         assert hierarchy.contains(name);
-        DefaultLocalConfigurationMetadata conf = new DefaultLocalConfigurationMetadata(name, description, visible, transitive, extendsFrom, hierarchy, buildDependencies);
+        DefaultLocalConfigurationMetadata conf = new DefaultLocalConfigurationMetadata(name, description, visible, transitive, extendsFrom, hierarchy, attributes, canBeConsumed, canBeResolved);
         allConfigurations.put(name, conf);
     }
 
+    @Override
     public void addDependency(LocalOriginDependencyMetadata dependency) {
         allDependencies.add(dependency);
     }
 
+    @Override
     public void addExclude(Exclude exclude) {
         allExcludes.add(exclude);
     }
@@ -89,34 +123,42 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         return componentIdentifier.getDisplayName();
     }
 
+    @Override
     public ModuleSource getSource() {
         return null;
     }
 
+    @Override
     public ComponentResolveMetadata withSource(ModuleSource source) {
         throw new UnsupportedOperationException();
     }
 
+    @Override
     public boolean isGenerated() {
         return false;
     }
 
+    @Override
     public boolean isChanging() {
         return false;
     }
 
+    @Override
     public String getStatus() {
         return status;
     }
 
+    @Override
     public List<String> getStatusScheme() {
         return DEFAULT_STATUS_SCHEME;
     }
 
+    @Override
     public ComponentIdentifier getComponentId() {
         return componentIdentifier;
     }
 
+    @Override
     public List<LocalOriginDependencyMetadata> getDependencies() {
         return allDependencies;
     }
@@ -130,10 +172,16 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         return allConfigurations.keySet();
     }
 
-    public DefaultLocalConfigurationMetadata getConfiguration(final String name) {
+    @Override
+    public LocalConfigurationMetadata getConfiguration(final String name) {
         return allConfigurations.get(name);
     }
 
+    @Override
+    public AttributesSchema getAttributesSchema() {
+        return attributesSchema;
+    }
+
     private class DefaultLocalConfigurationMetadata implements LocalConfigurationMetadata {
         private final String name;
         private final String description;
@@ -141,19 +189,33 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         private final boolean visible;
         private final Set<String> hierarchy;
         private final Set<String> extendsFrom;
-        private final TaskDependency buildDependencies;
+        private final AttributeContainerInternal attributes;
+        private final boolean canBeConsumed;
+        private final boolean canBeResolved;
 
-        private List<DependencyMetadata> configurationDependencies;
+        private List<LocalOriginDependencyMetadata> configurationDependencies;
+        private Set<LocalComponentArtifactMetadata> configurationArtifacts;
+        private Set<LocalFileDependencyMetadata> configurationFileDependencies;
         private ModuleExclusion configurationExclude;
 
-        private DefaultLocalConfigurationMetadata(String name, String description, boolean visible, boolean transitive, Set<String> extendsFrom, Set<String> hierarchy, TaskDependency buildDependencies) {
+        private DefaultLocalConfigurationMetadata(String name,
+                                                  String description,
+                                                  boolean visible,
+                                                  boolean transitive,
+                                                  Set<String> extendsFrom,
+                                                  Set<String> hierarchy,
+                                                  AttributeContainerInternal attributes,
+                                                  boolean canBeConsumed,
+                                                  boolean canBeResolved) {
             this.name = name;
             this.description = description;
             this.transitive = transitive;
             this.visible = visible;
             this.hierarchy = hierarchy;
             this.extendsFrom = extendsFrom;
-            this.buildDependencies = buildDependencies;
+            this.attributes = attributes;
+            this.canBeConsumed = canBeConsumed;
+            this.canBeResolved = canBeResolved;
         }
 
         @Override
@@ -166,41 +228,90 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         }
 
         @Override
-        public TaskDependency getDirectBuildDependencies() {
-            return buildDependencies;
-        }
-
         public String getDescription() {
             return description;
         }
 
+        @Override
         public Set<String> getExtendsFrom() {
             return extendsFrom;
         }
 
+        @Override
         public String getName() {
             return name;
         }
 
+        @Override
         public Set<String> getHierarchy() {
             return hierarchy;
         }
 
+        @Override
         public boolean isTransitive() {
             return transitive;
         }
 
+        @Override
         public boolean isVisible() {
             return visible;
         }
 
-        public List<DependencyMetadata> getDependencies() {
-            if (configurationDependencies == null) {
-                configurationDependencies = new ArrayList<DependencyMetadata>();
-                for (LocalOriginDependencyMetadata dependency : allDependencies) {
-                    if (include(dependency)) {
-                        configurationDependencies.add(dependency);
+        @Override
+        public AttributeContainerInternal getAttributes() {
+            return attributes;
+        }
+
+        @Override
+        public Set<? extends VariantMetadata> getVariants() {
+            Set<DefaultVariantMetadata> variants = allVariants.get(name);
+            if (variants.isEmpty()) {
+                variants = ImmutableSet.of(new DefaultVariantMetadata(attributes, getArtifacts()));
+            }
+            return variants;
+        }
+
+        @Override
+        public Set<LocalFileDependencyMetadata> getFiles() {
+            if (configurationFileDependencies == null) {
+                if (allFiles.isEmpty()) {
+                    configurationFileDependencies = ImmutableSet.of();
+                } else {
+                    ImmutableSet.Builder<LocalFileDependencyMetadata> result = ImmutableSet.builder();
+                    for (String confName : hierarchy) {
+                        for (LocalFileDependencyMetadata files : allFiles.get(confName)) {
+                            result.add(files);
+                        }
                     }
+                    configurationFileDependencies = result.build();
+                }
+            }
+            return configurationFileDependencies;
+        }
+
+        @Override
+        public boolean isCanBeConsumed() {
+            return canBeConsumed;
+        }
+
+        @Override
+        public boolean isCanBeResolved() {
+            return canBeResolved;
+        }
+
+        @Override
+        public List<? extends LocalOriginDependencyMetadata> getDependencies() {
+            if (configurationDependencies == null) {
+                if (allDependencies.isEmpty()) {
+                    configurationDependencies = ImmutableList.of();
+                } else {
+                    ImmutableList.Builder<LocalOriginDependencyMetadata> result = ImmutableList.builder();
+                    for (LocalOriginDependencyMetadata dependency : allDependencies) {
+                        if (include(dependency)) {
+                            result.add(dependency);
+                        }
+                    }
+                    configurationDependencies = result.build();
                 }
             }
             return configurationDependencies;
@@ -213,24 +324,41 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
         @Override
         public ModuleExclusion getExclusions() {
             if (configurationExclude == null) {
-                List<Exclude> filtered = Lists.newArrayList();
-                for (Exclude exclude : allExcludes) {
-                    for (String config : exclude.getConfigurations()) {
-                        if (hierarchy.contains(config)) {
-                            filtered.add(exclude);
-                            break;
+                if (allExcludes.isEmpty()) {
+                    configurationExclude = ModuleExclusions.excludeNone();
+                } else {
+                    List<Exclude> filtered = Lists.newArrayList();
+                    for (Exclude exclude : allExcludes) {
+                        for (String config : exclude.getConfigurations()) {
+                            if (hierarchy.contains(config)) {
+                                filtered.add(exclude);
+                                break;
+                            }
                         }
                     }
+                    configurationExclude = ModuleExclusions.excludeAny(filtered);
                 }
-                configurationExclude = ModuleExclusions.excludeAny(filtered);
             }
             return configurationExclude;
         }
 
-        public Set<ComponentArtifactMetadata> getArtifacts() {
-            return DefaultLocalComponentMetadata.getArtifacts(getHierarchy(), allArtifacts);
+        @Override
+        public Set<? extends LocalComponentArtifactMetadata> getArtifacts() {
+            if (configurationArtifacts == null) {
+                if (allArtifacts.isEmpty()) {
+                    configurationArtifacts = ImmutableSet.of();
+                } else {
+                    ImmutableSet.Builder<LocalComponentArtifactMetadata> result = ImmutableSet.builder();
+                    for (String config : hierarchy) {
+                        result.addAll(allArtifacts.get(config));
+                    }
+                    configurationArtifacts = result.build();
+                }
+            }
+            return configurationArtifacts;
         }
 
+        @Override
         public ComponentArtifactMetadata artifact(IvyArtifactName ivyArtifactName) {
             for (ComponentArtifactMetadata candidate : getArtifacts()) {
                 if (candidate.getName().equals(ivyArtifactName)) {
@@ -238,15 +366,7 @@ public class DefaultLocalComponentMetadata implements LocalComponentMetadata, Bu
                 }
             }
 
-            return new MissingLocalArtifactMetadata(componentIdentifier, id.toString(), ivyArtifactName);
+            return new MissingLocalArtifactMetadata(componentIdentifier, ivyArtifactName);
         }
     }
-
-    static Set<ComponentArtifactMetadata> getArtifacts(Set<String> configurationHierarchy, Multimap<String, ComponentArtifactMetadata> allArtifacts) {
-        Set<ComponentArtifactMetadata> artifacts = Sets.newLinkedHashSet();
-        for (String config : configurationHierarchy) {
-            artifacts.addAll(allArtifacts.get(config));
-        }
-        return artifacts;
-    }
 }
