@@ -16,7 +16,7 @@
 
 package org.gradle.internal.resolve.resolver;
 
-import org.gradle.internal.component.model.DependencyMetaData;
+import org.gradle.internal.component.model.DependencyMetadata;
 import org.gradle.internal.resolve.result.BuildableComponentIdResolveResult;
 
 public interface DependencyToComponentIdResolver {
@@ -25,5 +25,5 @@ public interface DependencyToComponentIdResolver {
      *
      * <p>At some point in the future, this should resolve to a set of candidates rather than a single instance.
      */
-    void resolve(DependencyMetaData dependency, BuildableComponentIdResolveResult result);
+    void resolve(DependencyMetadata dependency, BuildableComponentIdResolveResult result);
 }
