@@ -21,11 +21,11 @@ import com.google.common.collect.Iterables;
 import com.google.common.collect.Maps;
 import com.google.common.collect.Sets;
 import groovy.lang.Closure;
-import groovy.lang.GroovyObjectSupport;
 import org.gradle.api.Incubating;
 import org.gradle.api.JavaVersion;
 import org.gradle.api.Project;
 import org.gradle.api.artifacts.Configuration;
+import org.gradle.api.internal.project.ProjectInternal;
 import org.gradle.language.scala.ScalaPlatform;
 import org.gradle.plugins.ide.idea.model.internal.IdeaDependenciesProvider;
 import org.gradle.plugins.ide.internal.resolver.UnresolvedDependenciesLogger;
@@ -143,7 +143,7 @@ import java.util.Set;
  *
  * </pre>
  */
-public class IdeaModule extends GroovyObjectSupport {
+public class IdeaModule {
 
     private String name;
     private Set<File> sourceDirs;
@@ -268,14 +268,10 @@ public class IdeaModule extends GroovyObjectSupport {
         this.scopes = scopes;
     }
 
-    public boolean isDownloadSources() {
-        return downloadSources;
-    }
-
     /**
      * Whether to download and add sources associated with the dependency jars. <p> For example see docs for {@link IdeaModule}
      */
-    public boolean getDownloadSources() {
+    public boolean isDownloadSources() {
         return downloadSources;
     }
 
@@ -283,14 +279,10 @@ public class IdeaModule extends GroovyObjectSupport {
         this.downloadSources = downloadSources;
     }
 
-    public boolean isDownloadJavadoc() {
-        return downloadJavadoc;
-    }
-
     /**
      * Whether to download and add javadoc associated with the dependency jars. <p> For example see docs for {@link IdeaModule}
      */
-    public boolean getDownloadJavadoc() {
+    public boolean isDownloadJavadoc() {
         return downloadJavadoc;
     }
 
@@ -473,14 +465,10 @@ public class IdeaModule extends GroovyObjectSupport {
         this.pathFactory = pathFactory;
     }
 
-    public boolean isOffline() {
-        return offline;
-    }
-
     /**
      * If true then external artifacts (e.g. those found in repositories) will not be included in the resulting classpath (only project and local file dependencies will be included).
      */
-    public boolean getOffline() {
+    public boolean isOffline() {
         return offline;
     }
 
@@ -528,7 +516,8 @@ public class IdeaModule extends GroovyObjectSupport {
      * @return dependencies
      */
     public Set<Dependency> resolveDependencies() {
-        IdeaDependenciesProvider ideaDependenciesProvider = new IdeaDependenciesProvider();
+        ProjectInternal projectInternal = (ProjectInternal) project;
+        IdeaDependenciesProvider ideaDependenciesProvider = new IdeaDependenciesProvider(projectInternal.getServices());
         new UnresolvedDependenciesLogger().log(ideaDependenciesProvider.getUnresolvedDependencies(this));
         return ideaDependenciesProvider.provide(this);
     }
