@@ -18,7 +18,6 @@ package org.gradle.plugins.ide.internal.tooling;
 
 import org.gradle.api.JavaVersion;
 import org.gradle.api.Project;
-import org.gradle.api.internal.composite.CompositeBuildIdeProjectResolver;
 import org.gradle.api.plugins.JavaPluginConvention;
 import org.gradle.internal.service.ServiceRegistry;
 import org.gradle.plugins.ide.idea.IdeaPlugin;
@@ -48,7 +47,7 @@ import org.gradle.tooling.provider.model.ToolingModelBuilder;
 import java.io.File;
 import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
+import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.LinkedList;
 import java.util.List;
@@ -57,13 +56,11 @@ import java.util.Set;
 
 public class IdeaModelBuilder implements ToolingModelBuilder {
     private final GradleProjectBuilder gradleProjectBuilder;
-    private final CompositeBuildIdeProjectResolver compositeProjectMapper;
 
     private boolean offlineDependencyResolution;
 
     public IdeaModelBuilder(GradleProjectBuilder gradleProjectBuilder, ServiceRegistry services) {
         this.gradleProjectBuilder = gradleProjectBuilder;
-        compositeProjectMapper = new CompositeBuildIdeProjectResolver(services);
     }
 
     @Override
@@ -102,7 +99,7 @@ public class IdeaModelBuilder implements ToolingModelBuilder {
                 .setTargetBytecodeVersion(projectTargetBytecodeLevel)
                 .setJdk(DefaultInstalledJdk.current()));
 
-        Map<String, DefaultIdeaModule> modules = new HashMap<String, DefaultIdeaModule>();
+        Map<String, DefaultIdeaModule> modules = new LinkedHashMap<String, DefaultIdeaModule>();
         for (IdeaModule module : projectModel.getModules()) {
             appendModule(modules, module, out, rootGradleProject);
         }
