@@ -17,10 +17,11 @@
 package org.gradle.plugins.ide.internal.tooling.idea;
 
 import org.gradle.tooling.internal.gradle.DefaultGradleProject;
+import org.gradle.tooling.internal.gradle.DefaultProjectIdentifier;
 import org.gradle.tooling.internal.gradle.GradleProjectIdentity;
-import org.gradle.tooling.internal.protocol.DefaultIdeaModuleIdentifier;
 import org.gradle.tooling.model.idea.IdeaCompilerOutput;
 
+import java.io.File;
 import java.io.Serializable;
 import java.util.Collection;
 import java.util.Collections;
@@ -39,10 +40,6 @@ public class DefaultIdeaModule implements Serializable, GradleProjectIdentity {
 
     private DefaultIdeaJavaLanguageSettings javaLanguageSettings;
 
-    public DefaultIdeaModuleIdentifier getIdentifier() {
-        return new DefaultIdeaModuleIdentifier(gradleProject.getProjectDirectory());
-    }
-
     public String getName() {
         return name;
     }
@@ -100,11 +97,6 @@ public class DefaultIdeaModule implements Serializable, GradleProjectIdentity {
         return this;
     }
 
-    @Override
-    public String getPath() {
-        return gradleProject.getPath();
-    }
-
     public IdeaCompilerOutput getCompilerOutput() {
         return compilerOutput;
     }
@@ -123,6 +115,20 @@ public class DefaultIdeaModule implements Serializable, GradleProjectIdentity {
         return this;
     }
 
+    public DefaultProjectIdentifier getProjectIdentifier() {
+        return gradleProject.getProjectIdentifier();
+    }
+
+    @Override
+    public String getProjectPath() {
+        return getProjectIdentifier().getProjectPath();
+    }
+
+    @Override
+    public File getRootDir() {
+        return getProjectIdentifier().getBuildIdentifier().getRootDir();
+    }
+
     @Override
     public String toString() {
         return "IdeaModule{"
