@@ -28,8 +28,10 @@ import org.gradle.api.internal.initialization.DefaultClassLoaderScope;
 import org.gradle.api.internal.initialization.loadercache.ClassLoaderCache;
 import org.gradle.api.logging.Logger;
 import org.gradle.api.logging.Logging;
+import org.gradle.integtests.fixtures.daemon.DaemonLogsAnalyzer;
 import org.gradle.internal.UncheckedException;
 import org.gradle.internal.concurrent.CompositeStoppable;
+import org.gradle.internal.featurelifecycle.LoggingDeprecatedFeatureHandler;
 import org.gradle.internal.jvm.Jvm;
 import org.gradle.internal.logging.services.LoggingServiceRegistry;
 import org.gradle.internal.nativeintegration.services.NativeServices;
@@ -44,7 +46,7 @@ import org.gradle.test.fixtures.file.TestDirectoryProvider;
 import org.gradle.test.fixtures.file.TestFile;
 import org.gradle.testfixtures.internal.NativeServicesTestFixture;
 import org.gradle.util.CollectionUtils;
-import org.gradle.util.DeprecationLogger;
+import org.gradle.util.GradleVersion;
 
 import java.io.File;
 import java.io.IOException;
@@ -55,6 +57,7 @@ import java.nio.charset.Charset;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.LinkedHashMap;
 import java.util.LinkedHashSet;
 import java.util.List;
@@ -62,6 +65,7 @@ import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 
+import static org.gradle.internal.service.scopes.DefaultGradleUserHomeScopeServiceRegistry.REUSE_USER_HOME_SERVICES;
 import static org.gradle.integtests.fixtures.executer.AbstractGradleExecuter.CliDaemonArgument.*;
 import static org.gradle.integtests.fixtures.executer.OutputScrapingExecutionResult.STACK_TRACE_ELEMENT;
 import static org.gradle.util.CollectionUtils.collect;
@@ -81,6 +85,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     }
 
     private static final String DEBUG_SYSPROP = "org.gradle.integtest.debug";
+    private static final String LAUNCHER_DEBUG_SYSPROP = "org.gradle.integtest.launcher.debug";
     private static final String PROFILE_SYSPROP = "org.gradle.integtest.profile";
 
     protected static final List<String> DEBUG_ARGS = ImmutableList.of(
@@ -89,8 +94,9 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
 
     private final Logger logger;
 
-    protected final IntegrationTestBuildContext buildContext = new IntegrationTestBuildContext();
+    protected final IntegrationTestBuildContext buildContext;
 
+    private final Set<File> isolatedDaemonBaseDirs = new HashSet<File>();
     private final List<String> args = new ArrayList<String>();
     private final List<String> tasks = new ArrayList<String>();
     private boolean allowExtraLogging = true;
@@ -102,7 +108,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     private Map<String, String> environmentVars = new HashMap<String, String>();
     private List<File> initScripts = new ArrayList<File>();
     private String executable;
-    private TestFile gradleUserHomeDir = buildContext.getGradleUserHomeDir();
+    private TestFile gradleUserHomeDir;
     private File userHomeDir;
     private File javaHome;
     private File buildScript;
@@ -113,7 +119,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     private Locale defaultLocale;
     private int daemonIdleTimeoutSecs = 120;
     private boolean requireDaemon;
-    private File daemonBaseDir = buildContext.getDaemonBaseDir();
+    private File daemonBaseDir;
     private final List<String> buildJvmOpts = new ArrayList<String>();
     private final List<String> commandLineJvmOpts = new ArrayList<String>();
     private boolean useOnlyRequestedJvmOpts;
@@ -127,20 +133,39 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     private final Set<Action<? super GradleExecuter>> afterExecute = new LinkedHashSet<Action<? super GradleExecuter>>();
 
     private final TestDirectoryProvider testDirectoryProvider;
+    protected final GradleVersion gradleVersion;
     private final GradleDistribution distribution;
 
     private boolean debug = Boolean.getBoolean(DEBUG_SYSPROP);
+    private boolean debugLauncher = Boolean.getBoolean(LAUNCHER_DEBUG_SYSPROP);
     private String profiler = System.getProperty(PROFILE_SYSPROP, "");
 
     protected boolean interactive;
 
-    protected boolean noExplicitTmpDir;
+    private boolean noExplicitTmpDir;
     protected boolean noExplicitNativeServicesDir;
+    private boolean fullDeprecationStackTrace = true;
+    private boolean checkDeprecations = true;
+
+    private TestFile tmpDir;
+    private DurationMeasurement durationMeasurement;
 
     protected AbstractGradleExecuter(GradleDistribution distribution, TestDirectoryProvider testDirectoryProvider) {
+        this(distribution, testDirectoryProvider, GradleVersion.current());
+    }
+
+    protected AbstractGradleExecuter(GradleDistribution distribution, TestDirectoryProvider testDirectoryProvider, GradleVersion gradleVersion) {
+        this(distribution, testDirectoryProvider, gradleVersion, IntegrationTestBuildContext.INSTANCE);
+    }
+
+    protected AbstractGradleExecuter(GradleDistribution distribution, TestDirectoryProvider testDirectoryProvider, GradleVersion gradleVersion, IntegrationTestBuildContext buildContext) {
         this.distribution = distribution;
         this.testDirectoryProvider = testDirectoryProvider;
+        this.gradleVersion = gradleVersion;
         logger = Logging.getLogger(getClass());
+        this.buildContext = buildContext;
+        gradleUserHomeDir = buildContext.getGradleUserHomeDir();
+        daemonBaseDir = buildContext.getDaemonBaseDir();
     }
 
     protected Logger getLogger() {
@@ -171,8 +196,11 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         expectedDeprecationWarnings = 0;
         stackTraceChecksOn = true;
         debug = Boolean.getBoolean(DEBUG_SYSPROP);
+        debugLauncher = Boolean.getBoolean(LAUNCHER_DEBUG_SYSPROP);
         profiler = System.getProperty(PROFILE_SYSPROP, "");
         interactive = false;
+        checkDeprecations = true;
+        durationMeasurement = null;
         return this;
     }
 
@@ -263,6 +291,9 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         if (noExplicitNativeServicesDir) {
             executer.withNoExplicitNativeServicesDir();
         }
+        if (!fullDeprecationStackTrace) {
+            executer.withFullDeprecationStackTraceDisabled();
+        }
         if (defaultLocale != null) {
             executer.withDefaultLocale(defaultLocale);
         }
@@ -289,9 +320,19 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
             executer.requireDaemon();
         }
 
-        executer.withDebug(debug);
+        executer.startBuildProcessInDebugger(debug);
+        executer.startLauncherInDebugger(debugLauncher);
         executer.withProfiler(profiler);
         executer.withForceInteractive(interactive);
+
+        if (!checkDeprecations) {
+            executer.noDeprecationChecks();
+        }
+
+        if (durationMeasurement != null) {
+            executer.withDurationMeasurement(durationMeasurement);
+        }
+
         return executer;
     }
 
@@ -394,6 +435,9 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
             String value = entry.getValue();
             gradleInvocation.implicitLauncherJvmArgs.add(String.format("-D%s=%s", key, value));
         }
+        if (isDebugLauncher()) {
+            gradleInvocation.implicitLauncherJvmArgs.addAll(DEBUG_ARGS);
+        }
         gradleInvocation.implicitLauncherJvmArgs.add("-ea");
     }
 
@@ -590,14 +634,31 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         return daemonBaseDir.equals(buildContext.getDaemonBaseDir());
     }
 
-    protected boolean isUseDaemon() {
+    public boolean isUseDaemon() {
         CliDaemonArgument cliDaemonArgument = resolveCliDaemonArgument();
         if (cliDaemonArgument == DAEMON) {
             return true;
         }
         return requireDaemon;
     }
-    
+
+    /**
+     * Performs cleanup at completion of the test.
+     */
+    public void cleanup() {
+        cleanupIsolatedDaemons();
+    }
+
+    protected void cleanupIsolatedDaemons() {
+        for (File baseDir : isolatedDaemonBaseDirs) {
+            try {
+                new DaemonLogsAnalyzer(baseDir, gradleVersion.getVersion()).killAll();
+            } catch (Exception e) {
+                getLogger().warn("Problem killing isolated daemons of Gradle version " + gradleVersion + " in " + baseDir, e);
+            }
+        }
+    }
+
     // gets called by reflection from AbstractTestDirectoryProvider#closeCachedClassLoaders method
     public static void cleanupCachedClassLoaders() {
         ClassLoaderCache classLoaderCache = GLOBAL_SERVICES.get(ClassLoaderCache.class);
@@ -713,10 +774,16 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         if (!noExplicitNativeServicesDir) {
             properties.put(NativeServices.NATIVE_DIR_OVERRIDE, buildContext.getNativeServicesDir().getAbsolutePath());
         }
-        properties.put(DeprecationLogger.ORG_GRADLE_DEPRECATION_TRACE_PROPERTY_NAME, "true");
+        properties.put(LoggingDeprecatedFeatureHandler.ORG_GRADLE_DEPRECATION_TRACE_PROPERTY_NAME, Boolean.toString(fullDeprecationStackTrace));
 
+        if (gradleUserHomeDir != null && !gradleUserHomeDir.equals(buildContext.getGradleUserHomeDir())) {
+            properties.put(REUSE_USER_HOME_SERVICES, "false");
+        }
         if (!noExplicitTmpDir) {
-            String tmpDirPath = getDefaultTmpDir().createDir().getAbsolutePath();
+            if (tmpDir == null) {
+                tmpDir = getDefaultTmpDir();
+            }
+            String tmpDirPath = tmpDir.createDir().getAbsolutePath();
             if (!tmpDirPath.contains(" ") || (getDistribution().isSupportsSpacesInGradleAndJavaOpts() && supportsWhiteSpaceInEnvVars())) {
                 properties.put("java.io.tmpdir", tmpDirPath);
             }
@@ -749,6 +816,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         assert afterExecute.isEmpty() : "afterExecute actions are not implemented for async execution";
         fireBeforeExecute();
         assertCanExecute();
+        collectStateBeforeExecution();
         try {
             return doStart();
         } finally {
@@ -759,6 +827,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     public final ExecutionResult run() {
         fireBeforeExecute();
         assertCanExecute();
+        collectStateBeforeExecution();
         try {
             return doRun();
         } finally {
@@ -777,6 +846,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     public final ExecutionFailure runWithFailure() {
         fireBeforeExecute();
         assertCanExecute();
+        collectStateBeforeExecution();
         try {
             return doRunWithFailure();
         } finally {
@@ -784,6 +854,12 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         }
     }
 
+    private void collectStateBeforeExecution() {
+        if (!isSharedDaemons()) {
+            isolatedDaemonBaseDirs.add(daemonBaseDir);
+        }
+    }
+
     private void fireBeforeExecute() {
         beforeExecute.execute(this);
     }
@@ -820,10 +896,21 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         return this;
     }
 
+    @Override
+    public GradleExecuter withBuildCacheEnabled() {
+        return withArgument("-Dorg.gradle.cache.tasks=true");
+    }
+
+    @Override
+    public GradleExecuter withLocalBuildCache(File cacheDir) {
+        return withBuildCacheEnabled().withArgument("-Dorg.gradle.cache.tasks.directory=" + cacheDir.getAbsolutePath());
+    }
+
     protected Action<ExecutionResult> getResultAssertion() {
         return new Action<ExecutionResult>() {
             int expectedDeprecationWarnings = AbstractGradleExecuter.this.expectedDeprecationWarnings;
             boolean expectStackTraces = !AbstractGradleExecuter.this.stackTraceChecksOn;
+            boolean checkDeprecations = AbstractGradleExecuter.this.checkDeprecations;
 
             @Override
             public void execute(ExecutionResult executionResult) {
@@ -853,7 +940,7 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
                         // A javac warning, ignore
                         i++;
                     } else if (line.matches(".*\\s+deprecated.*")) {
-                        if (expectedDeprecationWarnings <= 0) {
+                        if (checkDeprecations && expectedDeprecationWarnings <= 0) {
                             throw new AssertionError(String.format("%s line %d contains a deprecation warning: %s%n=====%n%s%n=====%n", displayName, i+1, line, output));
                         }
                         expectedDeprecationWarnings--;
@@ -877,6 +964,10 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         expectedDeprecationWarnings++;
         return this;
     }
+    public GradleExecuter noDeprecationChecks() {
+        checkDeprecations = false;
+        return this;
+    }
 
     public GradleExecuter withEagerClassLoaderCreationCheckDisabled() {
         eagerClassLoaderCreationChecksOn = false;
@@ -911,11 +1002,22 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
     }
 
     @Override
-    public GradleExecuter withDebug(boolean flag) {
+    public GradleExecuter startBuildProcessInDebugger(boolean flag) {
         debug = flag;
         return this;
     }
 
+    @Override
+    public GradleExecuter startLauncherInDebugger(boolean flag) {
+        debugLauncher = flag;
+        return this;
+    }
+
+    @Override
+    public boolean isDebugLauncher() {
+        return debugLauncher;
+    }
+
     public GradleExecuter withProfiler(String args) {
         profiler = args;
         return this;
@@ -939,6 +1041,11 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         return this;
     }
 
+    public GradleExecuter withFullDeprecationStackTraceDisabled() {
+        fullDeprecationStackTrace = false;
+        return this;
+    }
+
     @Override
     public boolean isDebug() {
         return debug;
@@ -959,4 +1066,30 @@ public abstract class AbstractGradleExecuter implements GradleExecuter {
         final List<String> implicitLauncherJvmArgs = new ArrayList<String>();
     }
 
+    @Override
+    public void stop() {
+        cleanup();
+    }
+
+    @Override
+    public GradleExecuter withDurationMeasurement(DurationMeasurement durationMeasurement) {
+        this.durationMeasurement = durationMeasurement;
+        return this;
+    }
+
+    protected void startMeasurement() {
+        if (durationMeasurement != null) {
+            durationMeasurement.start();
+        }
+    }
+
+    protected void stopMeasurement() {
+        if (durationMeasurement != null) {
+            durationMeasurement.stop();
+        }
+    }
+
+    protected DurationMeasurement getDurationMeasurement() {
+        return durationMeasurement;
+    }
 }
