@@ -26,6 +26,8 @@ import java.io.File;
  */
 public class IntegrationTestBuildContext {
 
+    public static final IntegrationTestBuildContext INSTANCE = new IntegrationTestBuildContext();
+
     public TestFile getGradleHomeDir() {
         return file("integTest.gradleHomeDir", null);
     }
@@ -70,9 +72,19 @@ public class IntegrationTestBuildContext {
         return GradleVersion.current();
     }
 
+    /**
+     * The timestamped version used in the docs and the bin and all zips. This should be different to {@link GradleVersion#getVersion()}.
+     * Note that the binary distribution used for testing (testBinZip and intTestImage) has {@link GradleVersion#getVersion()} as version.
+     *
+     * @return timestamped version
+     */
+    public GradleVersion getDistZipVersion() {
+        return GradleVersion.version(System.getProperty("integTest.distZipVersion", GradleVersion.current().getVersion()));
+    }
+
     public TestFile getFatToolingApiJar() {
         TestFile toolingApiShadedJarDir = file("integTest.toolingApiShadedJarDir", "subprojects/tooling-api/build/shaded-jar");
-        TestFile fatToolingApiJar = new TestFile(toolingApiShadedJarDir, String.format("gradle-tooling-api-shaded-%s.jar", getVersion().getVersion()));
+        TestFile fatToolingApiJar = new TestFile(toolingApiShadedJarDir, String.format("gradle-tooling-api-shaded-%s.jar", getVersion().getBaseVersion().getVersion()));
 
         if (!fatToolingApiJar.exists()) {
             throw new IllegalStateException(String.format("The fat Tooling API JAR file does not exist: %s", fatToolingApiJar.getAbsolutePath()));
@@ -92,7 +104,7 @@ public class IntegrationTestBuildContext {
         return new ReleasedGradleDistribution(version, previousVersionDir.file(version));
     }
 
-    private static TestFile file(String propertyName, String defaultFile) {
+    protected static TestFile file(String propertyName, String defaultFile) {
         String path = System.getProperty(propertyName, defaultFile);
         if (path == null) {
             throw new RuntimeException(String.format("You must set the '%s' property to run the integration tests. The default passed was: '%s'",
