@@ -17,8 +17,7 @@
 package org.gradle.performance.fixture;
 
 import org.gradle.api.Action;
-import org.gradle.internal.Cast;
-import org.gradle.internal.UncheckedException;
+import org.gradle.internal.concurrent.CompositeStoppable;
 import org.gradle.performance.measure.MeasuredOperation;
 import org.gradle.performance.results.MeasuredOperationList;
 import org.gradle.util.GFileUtils;
@@ -33,11 +32,9 @@ import java.util.concurrent.atomic.AtomicBoolean;
 public class BuildExperimentRunner {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(BuildExperimentRunner.class);
-    public static final String HEAP_DUMP_PROPERTY = "org.gradle.performance.heapdump";
 
     private final DataCollector dataCollector;
     private final GradleSessionProvider executerProvider;
-    private final OperationTimer timer = new OperationTimer();
     private final HonestProfilerCollector honestProfiler;
 
     public enum Phase {
@@ -49,19 +46,10 @@ public class BuildExperimentRunner {
         return dataCollector;
     }
 
-    protected OperationTimer getTimer() {
-        return timer;
-    }
-
     public BuildExperimentRunner(GradleSessionProvider executerProvider) {
         this.executerProvider = executerProvider;
-        MemoryInfoCollector memoryInfoCollector = new MemoryInfoCollector();
-        memoryInfoCollector.setOutputFileName("build/totalMemoryUsed.txt");
-        BuildEventTimestampCollector buildEventTimestampCollector = new BuildEventTimestampCollector("build/buildEventTimestamps.txt");
-        GCLoggingCollector gcCollector = new GCLoggingCollector();
-        PerformanceCounterCollector performanceCounterCollector = new PerformanceCounterCollector();
         honestProfiler = new HonestProfilerCollector();
-        dataCollector = new CompositeDataCollector(memoryInfoCollector, gcCollector, buildEventTimestampCollector, performanceCounterCollector, new CompilationLoggingCollector(), honestProfiler);
+        dataCollector = new CompositeDataCollector(honestProfiler);
     }
 
     public HonestProfilerCollector getHonestProfiler() {
@@ -76,11 +64,11 @@ public class BuildExperimentRunner {
         InvocationSpec invocationSpec = experiment.getInvocation();
         if (invocationSpec instanceof GradleInvocationSpec) {
             GradleInvocationSpec invocation = (GradleInvocationSpec) invocationSpec;
+            honestProfiler.setInitiallyStopped(invocation.getUseDaemon());
             File workingDirectory = invocation.getWorkingDirectory();
             final List<String> additionalJvmOpts = dataCollector.getAdditionalJvmOpts(workingDirectory);
             final List<String> additionalArgs = new ArrayList<String>(dataCollector.getAdditionalArgs(workingDirectory));
             additionalArgs.add("-PbuildExperimentDisplayName=" + experiment.getDisplayName());
-            passHeapDumperParameter(additionalArgs);
 
             GradleInvocationSpec buildSpec = invocation.withAdditionalJvmOpts(additionalJvmOpts).withAdditionalArgs(additionalArgs);
             copyTemplateTo(experiment, workingDirectory);
@@ -91,18 +79,7 @@ public class BuildExperimentRunner {
                 performMeasurements(session, experiment, results, workingDirectory);
             } finally {
                 session.cleanup();
-            }
-        }
-    }
-
-    // activate org.gradle.performance.plugin.HeapDumper in the build
-    private void passHeapDumperParameter(List<String> additionalArgs) {
-        final String heapdumpValue = System.getProperty(HEAP_DUMP_PROPERTY);
-        if (heapdumpValue != null) {
-            if (heapdumpValue.equals("")) {
-                additionalArgs.add("-P" + HEAP_DUMP_PROPERTY);
-            } else {
-                additionalArgs.add("-P" + HEAP_DUMP_PROPERTY + "=" + heapdumpValue);
+                CompositeStoppable.stoppable(dataCollector).stop();
             }
         }
     }
@@ -113,18 +90,14 @@ public class BuildExperimentRunner {
         GFileUtils.copyDirectory(templateDir, workingDir);
     }
 
-    protected <S extends InvocationSpec, T extends InvocationCustomizer<S>> void performMeasurements(final InvocationExecutorProvider<T> session, BuildExperimentSpec experiment, MeasuredOperationList results, File projectDir) {
+    protected void performMeasurements(final InvocationExecutorProvider session, BuildExperimentSpec experiment, MeasuredOperationList results, File projectDir) {
         doWarmup(experiment, projectDir, session);
-        waitForMillis(experiment, experiment.getSleepAfterWarmUpMillis());
         doMeasure(experiment, results, projectDir, session);
     }
 
-    private <S extends InvocationSpec, T extends InvocationCustomizer<S>> void doMeasure(BuildExperimentSpec experiment, MeasuredOperationList results, File projectDir, InvocationExecutorProvider<T> session) {
+    private void doMeasure(BuildExperimentSpec experiment, MeasuredOperationList results, File projectDir, InvocationExecutorProvider session) {
         int invocationCount = invocationsForExperiment(experiment);
         for (int i = 0; i < invocationCount; i++) {
-            if (i > 0) {
-                waitForMillis(experiment, experiment.getSleepAfterTestRoundMillis());
-            }
             System.out.println();
             System.out.println(String.format("Test run #%s", i + 1));
             BuildExperimentInvocationInfo info = new DefaultBuildExperimentInvocationInfo(experiment, projectDir, Phase.MEASUREMENT, i + 1, invocationCount);
@@ -133,22 +106,25 @@ public class BuildExperimentRunner {
     }
 
     @SuppressWarnings("unchecked")
-    protected <S extends InvocationSpec, T extends InvocationCustomizer<S>> T createInvocationCustomizer(final BuildExperimentInvocationInfo info) {
+    protected InvocationCustomizer createInvocationCustomizer(final BuildExperimentInvocationInfo info) {
         if (info.getBuildExperimentSpec() instanceof GradleBuildExperimentSpec) {
-            return Cast.uncheckedCast(new GradleInvocationCustomizer() {
+            return new InvocationCustomizer() {
                 @Override
-                public GradleInvocationSpec customize(GradleInvocationSpec invocationSpec) {
+                public <T extends InvocationSpec> T customize(BuildExperimentInvocationInfo info, T invocationSpec) {
                     final List<String> iterationInfoArguments = createIterationInfoArguments(info.getPhase(), info.getIterationNumber(), info.getIterationMax());
-                    GradleInvocationSpec gradleInvocationSpec = invocationSpec.withAdditionalArgs(iterationInfoArguments);
+                    GradleInvocationSpec gradleInvocationSpec = ((GradleInvocationSpec) invocationSpec).withAdditionalArgs(iterationInfoArguments);
                     System.out.println("Run Gradle using JVM opts: " + gradleInvocationSpec.getJvmOpts());
-                    return gradleInvocationSpec;
+                    if(info.getBuildExperimentSpec().getInvocationCustomizer() != null) {
+                        gradleInvocationSpec = info.getBuildExperimentSpec().getInvocationCustomizer().customize(info, gradleInvocationSpec);
+                    }
+                    return (T) gradleInvocationSpec;
                 }
-            });
+            };
         }
         return null;
     }
 
-    private <S extends InvocationSpec, T extends InvocationCustomizer<S>> void doWarmup(BuildExperimentSpec experiment, File projectDir, InvocationExecutorProvider<T> session) {
+    private void doWarmup(BuildExperimentSpec experiment, File projectDir, InvocationExecutorProvider session) {
         int warmUpCount = warmupsForExperiment(experiment);
         for (int i = 0; i < warmUpCount; i++) {
             System.out.println();
@@ -174,11 +150,7 @@ public class BuildExperimentRunner {
         if (experiment.getInvocationCount() != null) {
             return experiment.getInvocationCount();
         }
-        if (usesDaemon(experiment)) {
-            return 20;
-        } else {
-            return 40;
-        }
+        return 20;
     }
 
     protected int warmupsForExperiment(BuildExperimentSpec experiment) {
@@ -190,7 +162,7 @@ public class BuildExperimentRunner {
             return experiment.getWarmUpCount();
         }
         if (usesDaemon(experiment)) {
-            return 10;
+            return 20;
         } else {
             return 1;
         }
@@ -206,39 +178,23 @@ public class BuildExperimentRunner {
         return false;
     }
 
-    // the JIT compiler seems to wait for idle period before compiling
-    protected void waitForMillis(BuildExperimentSpec experiment, long sleepTimeMillis) {
-        InvocationSpec invocation = experiment.getInvocation();
-        if (invocation instanceof GradleInvocationSpec) {
-            if (((GradleInvocationSpec) invocation).getBuildWillRunInDaemon() && sleepTimeMillis > 0L) {
-                System.out.println();
-                System.out.println(String.format("Waiting %d ms", sleepTimeMillis));
-                try {
-                    Thread.sleep(sleepTimeMillis);
-                } catch (InterruptedException e) {
-                    throw UncheckedException.throwAsUncheckedException(e);
-                }
-            }
-        }
-    }
-
-    protected <S extends InvocationSpec, T extends InvocationCustomizer<S>> void runOnce(
-        final InvocationExecutorProvider<T> session,
+    protected void runOnce(
+            final InvocationExecutorProvider session,
         final MeasuredOperationList results,
         final BuildExperimentInvocationInfo invocationInfo) {
         BuildExperimentSpec experiment = invocationInfo.getBuildExperimentSpec();
-        final Runnable runner = session.runner(Cast.<T>uncheckedCast(this.<S, T>createInvocationCustomizer(invocationInfo)));
+        final Action<MeasuredOperation> runner = session.runner(invocationInfo, wrapInvocationCustomizer(invocationInfo, createInvocationCustomizer(invocationInfo)));
 
         if (experiment.getListener() != null) {
             experiment.getListener().beforeInvocation(invocationInfo);
         }
 
-        MeasuredOperation operation = timer.measure(new Action<MeasuredOperation>() {
-            @Override
-            public void execute(MeasuredOperation measuredOperation) {
-                runner.run();
-            }
-        });
+        MeasuredOperation operation = new MeasuredOperation();
+        try {
+            runner.execute(operation);
+        } catch (Exception e) {
+            operation.setException(e);
+        }
 
         final AtomicBoolean omitMeasurement = new AtomicBoolean();
         if (experiment.getListener() != null) {
@@ -253,15 +209,35 @@ public class BuildExperimentRunner {
         if (!omitMeasurement.get()) {
             if (operation.getException() == null) {
                 dataCollector.collect(invocationInfo, operation);
-            }
-            if (operation.isValid()) {
-                results.add(operation);
+                if (operation.isValid()) {
+                    results.add(operation);
+                } else {
+                    LOGGER.error("Discarding invalid operation record {}", operation);
+                }
             } else {
-                LOGGER.error("Discarding invalid operation record {}", operation);
+                LOGGER.error("Discarding invalid operation record " + operation, operation.getException());
             }
         }
     }
 
+    private InvocationCustomizer wrapInvocationCustomizer(BuildExperimentInvocationInfo invocationInfo, final InvocationCustomizer invocationCustomizer) {
+        final InvocationCustomizer experimentSpecificCustomizer = invocationInfo.getBuildExperimentSpec().getInvocationCustomizer();
+        if (experimentSpecificCustomizer != null) {
+            if (invocationCustomizer != null) {
+                return new InvocationCustomizer() {
+                    @Override
+                    public <T extends InvocationSpec> T customize(BuildExperimentInvocationInfo info, T invocationSpec) {
+                        return experimentSpecificCustomizer.customize(info, invocationCustomizer.customize(info, invocationSpec));
+                    }
+                };
+            } else {
+                return experimentSpecificCustomizer;
+            }
+        } else {
+            return invocationCustomizer;
+        }
+    }
+
     protected List<String> createIterationInfoArguments(Phase phase, int iterationNumber, int iterationMax) {
         List<String> args = new ArrayList<String>(3);
         args.add("-PbuildExperimentPhase=" + phase.toString().toLowerCase());
