@@ -304,11 +304,18 @@ public class TestFile extends File {
      * Changes the last modified time for this file so that it is different to and smaller than its current last modified time, within file system resolution.
      */
     public TestFile makeOlder() {
-        // Just move back 2 seconds
-        setLastModified(lastModified() - 2000L);
+        makeOlder(this);
         return this;
     }
 
+    /**
+     * Changes the last modified time for the given file so that it is different to and smaller than its current last modified time, within file system resolution.
+     */
+    public static void makeOlder(File file) {
+        // Just move back 2 seconds
+        assert file.setLastModified(file.lastModified() - 2000L);
+    }
+
     /**
      * Creates a directory structure specified by the given closure.
      * <pre>
@@ -615,7 +622,7 @@ public class TestFile extends File {
 
     public void assertHasChangedSince(Snapshot snapshot) {
         Snapshot now = snapshot();
-        assertTrue(now.modTime != snapshot.modTime || !Arrays.equals(now.hash, snapshot.hash));
+        assertTrue(String.format("contents or modification time of %s have not changed", this), now.modTime != snapshot.modTime || !Arrays.equals(now.hash, snapshot.hash));
     }
 
     public void assertContentsHaveChangedSince(Snapshot snapshot) {
