@@ -27,10 +27,13 @@ import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.api.internal.project.IsolatedAntBuilder;
 import org.gradle.api.reporting.Reporting;
 import org.gradle.api.specs.Spec;
+import org.gradle.api.tasks.CacheableTask;
 import org.gradle.api.tasks.InputFiles;
 import org.gradle.api.tasks.Internal;
 import org.gradle.api.tasks.Nested;
 import org.gradle.api.tasks.Optional;
+import org.gradle.api.tasks.PathSensitive;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SourceSet;
 import org.gradle.api.tasks.TaskAction;
 import org.gradle.api.tasks.TaskCollection;
@@ -47,6 +50,7 @@ import java.util.concurrent.Callable;
 /**
  * Task to generate HTML, Xml and CSV reports of Jacoco coverage data.
  */
+@CacheableTask
 @Incubating
 public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsContainer> {
 
@@ -112,6 +116,7 @@ public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsC
     /**
      * Collection of execution data files to analyze.
      */
+    @PathSensitive(PathSensitivity.NONE)
     @InputFiles
     public FileCollection getExecutionData() {
         return executionData;
@@ -124,6 +129,7 @@ public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsC
     /**
      * Source sets that coverage should be reported for.
      */
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getSourceDirectories() {
         return sourceDirectories;
@@ -136,6 +142,7 @@ public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsC
     /**
      * Source sets that coverage should be reported for.
      */
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getClassDirectories() {
         return classDirectories;
@@ -149,6 +156,7 @@ public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsC
      * Additional class dirs that coverage data should be reported for.
      */
     @Optional
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getAdditionalClassDirs() {
         return additionalClassDirs;
@@ -162,6 +170,7 @@ public class JacocoReport extends JacocoBase implements Reporting<JacocoReportsC
      * Additional source dirs for the classes coverage data is being reported for.
      */
     @Optional
+    @PathSensitive(PathSensitivity.RELATIVE)
     @InputFiles
     public FileCollection getAdditionalSourceDirs() {
         return additionalSourceDirs;
