@@ -16,13 +16,11 @@
 
 package org.gradle.plugins.javascript.rhino.worker.internal;
 
-import org.gradle.api.Action;
 import org.gradle.api.logging.LogLevel;
 import org.gradle.plugins.javascript.rhino.worker.RhinoWorkerHandleFactory;
-import org.gradle.process.JavaExecSpec;
 import org.gradle.process.internal.JavaExecHandleBuilder;
-import org.gradle.process.internal.SingleUseWorkerProcessBuilder;
-import org.gradle.process.internal.WorkerProcessFactory;
+import org.gradle.process.internal.worker.SingleRequestWorkerProcessBuilder;
+import org.gradle.process.internal.worker.WorkerProcessFactory;
 
 import java.io.File;
 
@@ -35,17 +33,15 @@ public class DefaultRhinoWorkerHandleFactory implements RhinoWorkerHandleFactory
     }
 
     @Override
-    public <T> T create(Iterable<File> rhinoClasspath, Class<T> protocolType, Class<? extends T> workerImplementationType, LogLevel logLevel, Action<JavaExecSpec> javaExecSpecAction) {
-        SingleUseWorkerProcessBuilder<T> builder = workerProcessBuilderFactory.create(protocolType, workerImplementationType);
+    public <T> T create(Iterable<File> rhinoClasspath, Class<T> protocolType, Class<? extends T> workerImplementationType, LogLevel logLevel, File workingDir) {
+        SingleRequestWorkerProcessBuilder<T> builder = workerProcessBuilderFactory.singleRequestWorker(protocolType, workerImplementationType);
         builder.setBaseName("Gradle Rhino Worker");
         builder.setLogLevel(logLevel);
         builder.applicationClasspath(rhinoClasspath);
         builder.sharedPackages("org.mozilla.javascript");
 
         JavaExecHandleBuilder javaCommand = builder.getJavaCommand();
-        if (javaExecSpecAction != null) {
-            javaExecSpecAction.execute(javaCommand);
-        }
+        javaCommand.setWorkingDir(workingDir);
 
         return builder.build();
     }
