@@ -16,8 +16,8 @@
 
 package org.gradle.api.internal.tasks.compile.incremental.analyzer;
 
+import com.google.common.hash.HashCode;
 import org.gradle.api.internal.cache.Cache;
-import org.gradle.internal.hash.HashValue;
 
-public interface ClassAnalysisCache extends Cache<HashValue, ClassAnalysis> {
-}
\ No newline at end of file
+public interface ClassAnalysisCache extends Cache<HashCode, ClassAnalysis> {
+}
