@@ -19,6 +19,7 @@ package org.gradle.language.java.plugins;
 import com.google.common.collect.ImmutableSet;
 import org.gradle.api.*;
 import org.gradle.api.artifacts.dsl.RepositoryHandler;
+import org.gradle.api.attributes.AttributesSchema;
 import org.gradle.api.internal.artifacts.ArtifactDependencyResolver;
 import org.gradle.api.internal.artifacts.repositories.ResolutionAwareRepository;
 import org.gradle.internal.Transformers;
@@ -48,6 +49,7 @@ import org.gradle.platform.base.ComponentType;
 import org.gradle.platform.base.DependencySpec;
 import org.gradle.platform.base.TypeBuilder;
 import org.gradle.platform.base.internal.BinarySpecInternal;
+import org.gradle.util.DeprecationLogger;
 
 import java.io.File;
 import java.util.Collections;
@@ -145,14 +147,20 @@ public class JavaLanguagePlugin implements Plugin<Project> {
 
             @Override
             public void configureTask(Task task, BinarySpec binary, LanguageSourceSet sourceSet, ServiceRegistry serviceRegistry) {
-                PlatformJavaCompile compile = (PlatformJavaCompile) task;
+                final PlatformJavaCompile compile = (PlatformJavaCompile) task;
                 JavaSourceSet javaSourceSet = (JavaSourceSet) sourceSet;
                 JvmAssembly assembly = ((WithJvmAssembly) binary).getAssembly();
                 assembly.builtBy(compile);
 
                 compile.setDescription("Compiles " + javaSourceSet + ".");
                 compile.setDestinationDir(conventionalCompilationOutputDirFor(assembly));
-                compile.setDependencyCacheDir(new File(compile.getProject().getBuildDir(), "jvm-dep-cache"));
+                DeprecationLogger.whileDisabled(new Runnable() {
+                    @Override
+                    @SuppressWarnings("deprecation")
+                    public void run() {
+                        compile.setDependencyCacheDir(new File(compile.getProject().getBuildDir(), "jvm-dep-cache"));
+                    }
+                });
                 compile.dependsOn(javaSourceSet);
                 compile.setSource(javaSourceSet.getSource());
 
@@ -179,7 +187,8 @@ public class JavaLanguagePlugin implements Plugin<Project> {
                 List<ResolutionAwareRepository> resolutionAwareRepositories = collect(repositories, Transformers.cast(ResolutionAwareRepository.class));
                 ModelSchema<? extends BinarySpec> schema = schemaStore.getSchema(((BinarySpecInternal) binary).getPublicType());
                 VariantsMetaData variantsMetaData = DefaultVariantsMetaData.extractFrom(binary, schema);
-                return new SourceSetDependencyResolvingClasspath((BinarySpecInternal) binary, javaSourceSet, dependencies, dependencyResolver, variantsMetaData, resolutionAwareRepositories);
+                AttributesSchema attributesSchema = serviceRegistry.get(AttributesSchema.class);
+                return new SourceSetDependencyResolvingClasspath((BinarySpecInternal) binary, javaSourceSet, dependencies, dependencyResolver, variantsMetaData, resolutionAwareRepositories, attributesSchema);
             }
 
             private static Iterable<DependencySpec> compileDependencies(BinarySpec binary, DependentSourceSet sourceSet) {
