@@ -21,6 +21,10 @@ import org.gradle.api.logging.Logger;
 import org.gradle.api.logging.Logging;
 import org.gradle.api.specs.Spec;
 import org.gradle.internal.Pair;
+import org.gradle.internal.time.CountdownTimer;
+import org.gradle.internal.time.TimeProvider;
+import org.gradle.internal.time.Timers;
+import org.gradle.internal.time.TrueTimeProvider;
 import org.gradle.internal.UncheckedException;
 import org.gradle.internal.logging.progress.ProgressLogger;
 import org.gradle.internal.logging.progress.ProgressLoggerFactory;
@@ -62,6 +66,7 @@ public class DefaultDaemonConnector implements DaemonConnector {
     private final DaemonStarter daemonStarter;
     private final DaemonStartListener startListener;
     private final ProgressLoggerFactory progressLoggerFactory;
+    private final TimeProvider timeProvider = new TrueTimeProvider();
     private long connectTimeout = DefaultDaemonConnector.DEFAULT_CONNECT_TIMEOUT;
 
     public DefaultDaemonConnector(DaemonRegistry daemonRegistry, OutgoingConnector connector, DaemonStarter daemonStarter, DaemonStartListener startListener, ProgressLoggerFactory progressLoggerFactory) {
@@ -151,8 +156,8 @@ public class DefaultDaemonConnector implements DaemonConnector {
         final Collection<DaemonInfo> compatibleCanceledDaemons = getCompatibleDaemons(canceledBusy.getLeft(), constraint);
         if (!compatibleCanceledDaemons.isEmpty()) {
             LOGGER.info(DaemonMessages.WAITING_ON_CANCELED);
-            long waitUntil = System.currentTimeMillis() + CANCELED_WAIT_TIMEOUT;
-            while (connection == null && System.currentTimeMillis() < waitUntil) {
+            CountdownTimer timer = Timers.startTimer(CANCELED_WAIT_TIMEOUT);
+            while (connection == null && !timer.hasExpired()) {
                 try {
                     sleep(200);
                     connection = connectToIdleDaemon(daemonRegistry.getIdle(), constraint);
@@ -202,7 +207,7 @@ public class DefaultDaemonConnector implements DaemonConnector {
             .start("Starting Gradle Daemon", "Starting Daemon");
         final DaemonStartupInfo startupInfo = daemonStarter.startDaemon();
         LOGGER.debug("Started Gradle daemon {}", startupInfo);
-        long expiry = System.currentTimeMillis() + connectTimeout;
+        CountdownTimer timer = Timers.startTimer(connectTimeout);
         try {
             do {
                 DaemonClientConnection daemonConnection = connectToDaemonWithId(startupInfo, constraint);
@@ -215,7 +220,7 @@ public class DefaultDaemonConnector implements DaemonConnector {
                 } catch (InterruptedException e) {
                     throw UncheckedException.throwAsUncheckedException(e);
                 }
-            } while (System.currentTimeMillis() < expiry);
+            } while (!timer.hasExpired());
         } finally {
             progressLogger.completed();
         }
