@@ -15,7 +15,6 @@
  */
 package org.gradle.nativeplatform.tasks;
 
-import groovy.lang.GroovyObject;
 import org.gradle.api.Incubating;
 import org.gradle.api.tasks.ParallelizableTask;
 import org.gradle.nativeplatform.internal.DefaultLinkerSpec;
@@ -26,8 +25,7 @@ import org.gradle.nativeplatform.internal.LinkerSpec;
  */
 @Incubating
 @ParallelizableTask
-public class LinkExecutable extends AbstractLinkTask implements GroovyObject {
-
+public class LinkExecutable extends AbstractLinkTask {
     @Override
     protected LinkerSpec createLinkerSpec() {
         return new DefaultLinkerSpec();
