@@ -17,15 +17,16 @@ package org.gradle.api.internal.tasks;
 
 import groovy.lang.Closure;
 import org.apache.commons.lang.StringUtils;
+import org.gradle.api.Action;
 import org.gradle.api.file.FileCollection;
 import org.gradle.api.file.FileTreeElement;
 import org.gradle.api.file.SourceDirectorySet;
+import org.gradle.api.internal.ClosureBackedAction;
 import org.gradle.api.internal.file.SourceDirectorySetFactory;
 import org.gradle.api.internal.jvm.ClassDirectoryBinaryNamingScheme;
 import org.gradle.api.specs.Spec;
 import org.gradle.api.tasks.SourceSet;
 import org.gradle.api.tasks.SourceSetOutput;
-import org.gradle.util.ConfigureUtil;
 import org.gradle.util.GUtil;
 
 public class DefaultSourceSet implements SourceSet {
@@ -45,7 +46,7 @@ public class DefaultSourceSet implements SourceSet {
         displayName = GUtil.toWords(this.name);
         namingScheme = new ClassDirectoryBinaryNamingScheme(name);
 
-        String javaSrcDisplayName = String.format("%s Java source", displayName);
+        String javaSrcDisplayName = displayName + " Java source";
 
         javaSource = sourceDirectorySetFactory.create(javaSrcDisplayName);
         javaSource.getFilter().include("**/*.java");
@@ -54,7 +55,7 @@ public class DefaultSourceSet implements SourceSet {
         allJavaSource.getFilter().include("**/*.java");
         allJavaSource.source(javaSource);
 
-        String resourcesDisplayName = String.format("%s resources", displayName);
+        String resourcesDisplayName = displayName + " resources";
         resources = sourceDirectorySetFactory.create(resourcesDisplayName);
         resources.getFilter().exclude(new Spec<FileTreeElement>() {
             public boolean isSatisfiedBy(FileTreeElement element) {
@@ -62,7 +63,7 @@ public class DefaultSourceSet implements SourceSet {
             }
         });
 
-        String allSourceDisplayName = String.format("%s source", displayName);
+        String allSourceDisplayName = displayName + " source";
         allSource = sourceDirectorySetFactory.create(allSourceDisplayName);
         allSource.source(resources);
         allSource.source(javaSource);
@@ -74,7 +75,7 @@ public class DefaultSourceSet implements SourceSet {
 
     @Override
     public String toString() {
-        return String.format("source set '%s'", getDisplayName());
+        return "source set '" + getDisplayName() + "'";
     }
 
     public String getDisplayName() {
@@ -110,20 +111,20 @@ public class DefaultSourceSet implements SourceSet {
     }
 
     public String getCompileConfigurationName() {
-        return StringUtils.uncapitalize(String.format("%sCompile", getTaskBaseName()));
+        return StringUtils.uncapitalize(getTaskBaseName() + "Compile");
     }
 
     public String getRuntimeConfigurationName() {
-        return StringUtils.uncapitalize(String.format("%sRuntime", getTaskBaseName()));
+        return StringUtils.uncapitalize(getTaskBaseName() + "Runtime");
     }
 
     public String getCompileOnlyConfigurationName() {
-        return StringUtils.uncapitalize(String.format("%sCompileOnly", getTaskBaseName()));
+        return StringUtils.uncapitalize(getTaskBaseName() + "CompileOnly");
     }
 
     @Override
     public String getCompileClasspathConfigurationName() {
-        return StringUtils.uncapitalize(String.format("%sCompileClasspath", getTaskBaseName()));
+        return StringUtils.uncapitalize(getTaskBaseName() + "CompileClasspath");
     }
 
     public SourceSetOutput getOutput() {
@@ -160,7 +161,12 @@ public class DefaultSourceSet implements SourceSet {
     }
 
     public SourceSet java(Closure configureClosure) {
-        ConfigureUtil.configure(configureClosure, getJava());
+        return java(ClosureBackedAction.of(configureClosure));
+    }
+
+    @Override
+    public SourceSet java(Action<? super SourceDirectorySet> configureAction) {
+        configureAction.execute(getJava());
         return this;
     }
 
@@ -173,7 +179,12 @@ public class DefaultSourceSet implements SourceSet {
     }
 
     public SourceSet resources(Closure configureClosure) {
-        ConfigureUtil.configure(configureClosure, getResources());
+        return resources(ClosureBackedAction.of(configureClosure));
+    }
+
+    @Override
+    public SourceSet resources(Action<? super SourceDirectorySet> configureAction) {
+        configureAction.execute(getResources());
         return this;
     }
 
