@@ -38,11 +38,13 @@ import org.gradle.api.internal.tasks.SourceSetCompileClasspath;
 import org.gradle.api.internal.tasks.testing.NoMatchingTestsReporter;
 import org.gradle.api.reporting.ReportingExtension;
 import org.gradle.api.tasks.Copy;
+import org.gradle.api.tasks.PathSensitivity;
 import org.gradle.api.tasks.SourceSet;
 import org.gradle.api.tasks.compile.AbstractCompile;
 import org.gradle.api.tasks.compile.JavaCompile;
 import org.gradle.api.tasks.javadoc.Javadoc;
 import org.gradle.api.tasks.testing.Test;
+import org.gradle.internal.Factory;
 import org.gradle.internal.reflect.Instantiator;
 import org.gradle.jvm.Classpath;
 import org.gradle.jvm.platform.internal.DefaultJavaPlatform;
@@ -61,6 +63,7 @@ import org.gradle.platform.base.BinaryContainer;
 import org.gradle.platform.base.internal.BinarySpecInternal;
 import org.gradle.platform.base.internal.DefaultComponentSpecIdentifier;
 import org.gradle.platform.base.plugins.BinaryBasePlugin;
+import org.gradle.util.DeprecationLogger;
 import org.gradle.util.WrapUtil;
 
 import javax.inject.Inject;
@@ -274,11 +277,18 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
             }
         });
         project.getTasks().withType(JavaCompile.class, new Action<JavaCompile>() {
+            @Override
             public void execute(final JavaCompile compile) {
                 ConventionMapping conventionMapping = compile.getConventionMapping();
                 conventionMapping.map("dependencyCacheDir", new Callable<Object>() {
+                    @Override
                     public Object call() throws Exception {
-                        return javaConvention.getDependencyCacheDir();
+                        return DeprecationLogger.whileDisabled(new Factory<Object>() {
+                            @Override
+                            public Object create() {
+                                return javaConvention.getDependencyCacheDir();
+                            }
+                        });
                     }
                 });
             }
@@ -314,6 +324,14 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
         buildTask.setDescription("Assembles and tests this project and all projects that depend on it.");
         buildTask.setGroup(BasePlugin.BUILD_GROUP);
         buildTask.dependsOn(BUILD_TASK_NAME);
+        buildTask.doFirst(new Action<Task>() {
+            @Override
+            public void execute(Task task) {
+                if (!task.getProject().getGradle().getIncludedBuilds().isEmpty()) {
+                    task.getProject().getLogger().warn("[composite-build] Warning: `" + task.getPath() + "` task does not build included builds.");
+                }
+            }
+        });
     }
 
     private void configureTest(final Project project, final JavaPluginConvention convention) {
@@ -352,7 +370,10 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
             //configure inputs so that the test task is skipped when there are no source files.
             //unfortunately, this only applies when 'test.single' is *not* applied
             //We should fix this distinction, the behavior with 'test.single' or without it should be the same
-            test.getInputs().source(test.getCandidateClassFiles());
+            test.getInputs().files(test.getCandidateClassFiles())
+                .withPropertyName("nonEmptyCandidateClassFiles")
+                .withPathSensitivity(PathSensitivity.RELATIVE)
+                .skipWhenEmpty();
             return;
         }
         test.prependParallelSafeAction(new Action<Task>() {
@@ -379,17 +400,17 @@ public class JavaBasePlugin implements Plugin<ProjectInternal> {
 
         xmlReport.getConventionMapping().map("destination", new Callable<Object>() {
             public Object call() throws Exception {
-                return convention.getTestResultsDir();
+                return new File(convention.getTestResultsDir(), test.getName());
             }
         });
         htmlReport.getConventionMapping().map("destination", new Callable<Object>() {
             public Object call() throws Exception {
-                return convention.getTestReportDir();
+                return new File(convention.getTestReportDir(), test.getName());
             }
         });
         test.getConventionMapping().map("binResultsDir", new Callable<Object>() {
             public Object call() throws Exception {
-                return new File(convention.getTestResultsDir(), "binary/" + test.getName());
+                return new File(convention.getTestResultsDir(), test.getName() + "/binary");
             }
         });
         test.workingDir(project.getProjectDir());
