@@ -31,11 +31,13 @@ import org.gradle.tooling.GradleConnectionException;
 import org.gradle.tooling.GradleConnector;
 import org.gradle.tooling.ProjectConnection;
 import org.gradle.tooling.UnsupportedVersionException;
+import org.gradle.tooling.events.OperationType;
 import org.gradle.tooling.events.ProgressEvent;
 import org.gradle.tooling.events.ProgressListener;
 import org.gradle.tooling.events.task.TaskFailureResult;
 import org.gradle.tooling.events.task.TaskFinishEvent;
 import org.gradle.tooling.events.task.TaskOperationResult;
+import org.gradle.tooling.events.task.TaskProgressEvent;
 import org.gradle.tooling.events.task.TaskSkippedResult;
 import org.gradle.tooling.events.task.TaskStartEvent;
 import org.gradle.tooling.events.task.TaskSuccessResult;
@@ -109,7 +111,7 @@ public class ToolingApiGradleExecutor implements GradleExecutor {
             launcher.setStandardOutput(new NoCloseOutputStream(teeOutput(syncOutput, parameters.getStandardOutput())));
             launcher.setStandardError(new NoCloseOutputStream(teeOutput(syncOutput, parameters.getStandardError())));
 
-            launcher.addProgressListener(new TaskExecutionProgressListener(tasks));
+            launcher.addProgressListener(new TaskExecutionProgressListener(tasks), OperationType.TASK);
 
             launcher.withArguments(parameters.getBuildArgs().toArray(new String[0]));
             launcher.setJvmArguments(parameters.getJvmArgs().toArray(new String[0]));
@@ -192,11 +194,17 @@ public class ToolingApiGradleExecutor implements GradleExecutor {
         public void statusChanged(ProgressEvent event) {
             if (event instanceof TaskStartEvent) {
                 TaskStartEvent taskStartEvent = (TaskStartEvent) event;
+                if (!accept(taskStartEvent)) {
+                    return;
+                }
                 order.put(taskStartEvent.getDescriptor().getTaskPath(), tasks.size());
                 tasks.add(null);
             }
             if (event instanceof TaskFinishEvent) {
                 TaskFinishEvent taskFinishEvent = (TaskFinishEvent) event;
+                if (!accept(taskFinishEvent)) {
+                    return;
+                }
                 String taskPath = taskFinishEvent.getDescriptor().getTaskPath();
                 TaskOperationResult result = taskFinishEvent.getResult();
                 final Integer index = order.get(taskPath);
@@ -207,11 +215,18 @@ public class ToolingApiGradleExecutor implements GradleExecutor {
             }
         }
 
+        private boolean accept(TaskProgressEvent event) {
+            // Exclude tasks from `buildSrc`
+            return !event.getDescriptor().getTaskPath().startsWith(":buildSrc");
+        }
+
         private BuildTask determineBuildTask(TaskOperationResult result, String taskPath) {
             if (isFailed(result)) {
                 return createBuildTask(taskPath, FAILED);
             } else if (isSkipped(result)) {
                 return createBuildTask(taskPath, SKIPPED);
+            } else if (isFromCache(result)) {
+                return createBuildTask(taskPath, FROM_CACHE);
             } else if (isUpToDate(result)) {
                 return createBuildTask(taskPath, UP_TO_DATE);
             }
@@ -234,5 +249,9 @@ public class ToolingApiGradleExecutor implements GradleExecutor {
         private boolean isUpToDate(TaskOperationResult result) {
             return result instanceof TaskSuccessResult && ((TaskSuccessResult) result).isUpToDate();
         }
+
+        private boolean isFromCache(TaskOperationResult result) {
+            return result instanceof TaskSuccessResult && ((TaskSuccessResult) result).isFromCache();
+        }
     }
 }
