@@ -15,10 +15,10 @@
  */
 package org.gradle.api.internal.tasks.testing.detection;
 
-import org.gradle.api.file.FileCollection;
 import org.gradle.api.internal.tasks.testing.TestClassProcessor;
 
 import java.io.File;
+import java.util.Set;
 
 public interface TestFrameworkDetector {
     void startDetection(TestClassProcessor testClassProcessor);
@@ -27,5 +27,5 @@ public interface TestFrameworkDetector {
 
     void setTestClassesDirectory(File testClassesDir);
 
-    void setTestClasspath(FileCollection classpath);
+    void setTestClasspath(Set<File> classpath);
 }
